@@ -97,53 +97,60 @@ char argtyp2(CSOUND *csound, char *s);
 #define FLOAT_COMPARE(x,y)  (fabs((double) (x) / (double) (y) - 1.0) > 5.0e-7)
 #endif
 
+#define lblclear(x)
+#if 0
 /** This function body copied from rdorch.c, not currently used */
 static void lblclear(CSOUND *csound)
 {
     /* ST(lblcnt) = 0; */
 }
+#endif
 
-static void resetouts(CSOUND *csound)
+static inline void resetouts(CSOUND *csound)
 {
     csound->acount = csound->kcount = csound->icount = 0;
     csound->Bcount = csound->bcount = 0;
 }
 
-TEXT *create_text(CSOUND *csound) {
+/* Unused */
+#if 0
+TEXT *create_text(CSOUND *csound)
+{
     TEXT        *tp = (TEXT *)mcalloc(csound, (int32)sizeof(TEXT));
     return tp;
 }
+#endif
 
-int tree_arg_list_count(TREE * root) {
+int tree_arg_list_count(TREE * root)
+{
     int count = 0;
-
     TREE * current = root;
 
     while(current != NULL) {
-        current = current->next;
-        count++;
+      current = current->next;
+      count++;
     }
-
     return count;
 }
 
 /**
  * Returns last OPTXT of OPTXT chain optxt
  */
-static OPTXT * last_optxt(OPTXT *optxt) {
+static OPTXT * last_optxt(OPTXT *optxt)
+{
     OPTXT *current = optxt;
 
     while(current->nxtop != NULL) {
-        current = current->nxtop;
+      current = current->nxtop;
     }
-
     return current;
 }
 
 /**
  * Append OPTXT op2 to end of OPTXT chain op1
  */
-static void append_optxt(OPTXT *op1, OPTXT *op2) {
+static void append_optxt(OPTXT *op1, OPTXT *op2)
+{
     last_optxt(op1)->nxtop = op2;
 }
 
@@ -154,7 +161,8 @@ static void append_optxt(OPTXT *op1, OPTXT *op2) {
  * only once if used multiple times; to be removed or reused in context
  * of redoing namset functions (if even desirable)
  */
-/* void update_lclcount(CSOUND *csound, INSTRTXT *ip, TREE *argslist) {
+/* void update_lclcount(CSOUND *csound, INSTRTXT *ip, TREE *argslist)
+{
     TREE * current = argslist;
 
     while(current != NULL) {
@@ -184,149 +192,145 @@ static void append_optxt(OPTXT *op1, OPTXT *op2) {
     }
 }*/
 
-void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep) {
-     int n = tp->inlist->count;
-     char *s;
-
-     char *types = ep->intypes;
-
-     int nreqd = -1;
-     char      tfound = '\0', treqd;
-
-     if (nreqd < 0)    /* for other opcodes */
-        nreqd = strlen(types = ep->intypes);
-
-      /*if (n > nreqd) {*/                  /* IV - Oct 24 2002: end of new code */
-        /*if ((treqd = types[nreqd-1]) == 'n') {*/  /* indef args: */
-        /*  if (!(incnt & 01))*/                    /* require odd */
-            /*synterr(csound, Str("missing or extra arg"));*/
-        /*}*/       /* IV - Sep 1 2002: added 'M' */
-        /*else if (treqd != 'm' && treqd != 'z' && treqd != 'y' &&*/
-                 /*treqd != 'Z' && treqd != 'M' && treqd != 'N')*/ /* else any no */
-          /*synterr(csound, Str("too many input args"));*/
-      /*}*/
-
-     while (n--) {                     /* inargs:   */
-        s = tp->inlist->arg[n];
-
-        if (n >= nreqd) {               /* det type required */
-          switch (types[nreqd-1]) {
-            case 'M':
-            case 'N':
-            case 'Z':
-            case 'y':
-            case 'z':   treqd = types[nreqd-1]; break;
-            default:    treqd = 'i';    /*   (indef in-type) */
-          }
-        }
-        else treqd = types[n];          /*       or given)   */
-        if (treqd == 'l') {             /* if arg takes lbl  */
-          csound->DebugMsg(csound, "treqd = l");
-          /*lblrequest(csound, s);*/        /*      req a search */
-          continue;                     /*      chk it later */
-        }
-        tfound = argtyp2(csound, s);     /* else get arg type */
-        /* IV - Oct 31 2002 */
-        /*tfound_m = ST(typemask_tabl)[(unsigned char) tfound];
-        if (!(tfound_m & (ARGTYP_c|ARGTYP_p)) && !ST(lgprevdef) && *s != '"') {
-          synterr(csound, Str("input arg '%s' used before defined"), s);
-        }*/
-        csound->DebugMsg(csound, "treqd %c, tfound %c", treqd, tfound);
-        if (tfound == 'a' && n < 31)    /* JMC added for FOG */
-                                        /* 4 for FOF, 8 for FOG; expanded to 15  */
-          tp->xincod |= (1 << n);
-        if (tfound == 'S' && n < 31)
-          tp->xincod_str |= (1 << n);
-        /* IV - Oct 31 2002: simplified code */
-       /* if (!(tfound_m & ST(typemask_tabl_in)[(unsigned char) treqd])) { */
-          /* check for exceptional types */
-          /*switch (treqd) {*/
-          /*case 'Z':*/                             /* indef kakaka ... */
-            /*if (!(tfound_m & (n & 1 ? ARGTYP_a : ARGTYP_ipcrk)))
-              intyperr(csound, n, tfound, treqd);
-            break;
-          case 'x':
-            treqd_m = ARGTYP_ipcr;*/              /* also allows i-rate */
-          /*case 's':*/                             /* a- or k-rate */
-            /*treqd_m |= ARGTYP_a | ARGTYP_k;
-            if (tfound_m & treqd_m) {
-              if (tfound == 'a' && tp->outlist != ST(nullist)) {*/
-                /*long outyp_m =*/                  /* ??? */
-                  /*ST(typemask_tabl)[(unsigned char) argtyp(csound,
-                                                       tp->outlist->arg[0])];
-                if (outyp_m & (ARGTYP_a | ARGTYP_w)) break;
-              }
-              else
-                break;
-            }
-          default:
-            intyperr(csound, n, tfound, treqd);
-            break;
-          }
-        }*/
-      }
-      csound->DebugMsg(csound, "xincod = %d", tp->xincod);
-}
-
-void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep) {
-     int n = tp->outlist->count;
-     char *s;
-
-     char *types = ep->outypes;
-
-     int nreqd = -1;
-     char      tfound = '\0', treqd;
+void set_xincod(CSOUND *csound, TEXT *tp, OENTRY *ep)
+{
+    int n = tp->inlist->count;
+    char *s;
+    char *types = ep->intypes;
+    int nreqd = -1;
+    char      tfound = '\0', treqd;
 
     if (nreqd < 0)    /* for other opcodes */
-        nreqd = strlen(types = ep->outypes);
+      nreqd = strlen(types = ep->intypes);
+
+    /*if (n > nreqd) {*/                  /* IV - Oct 24 2002: end of new code */
+    /*if ((treqd = types[nreqd-1]) == 'n') {*/  /* indef args: */
+    /*  if (!(incnt & 01))*/                    /* require odd */
+    /*synterr(csound, Str("missing or extra arg"));*/
+    /*}*/       /* IV - Sep 1 2002: added 'M' */
+    /*else if (treqd != 'm' && treqd != 'z' && treqd != 'y' &&*/
+    /*treqd != 'Z' && treqd != 'M' && treqd != 'N')*/ /* else any no */
+    /*synterr(csound, Str("too many input args"));*/
+    /*}*/
+
+    while (n--) {                     /* inargs:   */
+      s = tp->inlist->arg[n];
+
+      if (n >= nreqd) {               /* det type required */
+        switch (types[nreqd-1]) {
+        case 'M':
+        case 'N':
+        case 'Z':
+        case 'y':
+        case 'z':   treqd = types[nreqd-1]; break;
+        default:    treqd = 'i';    /*   (indef in-type) */
+        }
+      }
+      else treqd = types[n];          /*       or given)   */
+      if (treqd == 'l') {             /* if arg takes lbl  */
+        csound->DebugMsg(csound, "treqd = l");
+        /*lblrequest(csound, s);*/        /*      req a search */
+        continue;                     /*      chk it later */
+      }
+      tfound = argtyp2(csound, s);     /* else get arg type */
+      /* IV - Oct 31 2002 */
+      /*tfound_m = ST(typemask_tabl)[(unsigned char) tfound];
+        if (!(tfound_m & (ARGTYP_c|ARGTYP_p)) && !ST(lgprevdef) && *s != '"') {
+        synterr(csound, Str("input arg '%s' used before defined"), s);
+        }*/
+      csound->DebugMsg(csound, "treqd %c, tfound %c", treqd, tfound);
+      if (tfound == 'a' && n < 31)    /* JMC added for FOG */
+                                      /* 4 for FOF, 8 for FOG; expanded to 15  */
+        tp->xincod |= (1 << n);
+      if (tfound == 'S' && n < 31)
+        tp->xincod_str |= (1 << n);
+      /* IV - Oct 31 2002: simplified code */
+      /* if (!(tfound_m & ST(typemask_tabl_in)[(unsigned char) treqd])) { */
+      /* check for exceptional types */
+      /*switch (treqd) {*/
+      /*case 'Z':*/                             /* indef kakaka ... */
+      /*if (!(tfound_m & (n & 1 ? ARGTYP_a : ARGTYP_ipcrk)))
+        intyperr(csound, n, tfound, treqd);
+        break;
+        case 'x':
+        treqd_m = ARGTYP_ipcr;*/              /* also allows i-rate */
+      /*case 's':*/                             /* a- or k-rate */
+      /*treqd_m |= ARGTYP_a | ARGTYP_k;
+        if (tfound_m & treqd_m) {
+        if (tfound == 'a' && tp->outlist != ST(nullist)) {*/
+      /*long outyp_m =*/                  /* ??? */
+      /*ST(typemask_tabl)[(unsigned char) argtyp(csound,
+        tp->outlist->arg[0])];
+        if (outyp_m & (ARGTYP_a | ARGTYP_w)) break;
+        }
+        else
+        break;
+        }
+        default:
+        intyperr(csound, n, tfound, treqd);
+        break;
+        }
+        }*/
+    }
+    csound->DebugMsg(csound, "xincod = %d", tp->xincod);
+}
+
+void set_xoutcod(CSOUND *csound, TEXT *tp, OENTRY *ep)
+{
+    int n = tp->outlist->count;
+    char *s;
+    char *types = ep->outypes;
+    int nreqd = -1;
+    char      tfound = '\0', treqd;
+
+    if (nreqd < 0)    /* for other opcodes */
+      nreqd = strlen(types = ep->outypes);
 /*      if ((n != nreqd) &&       */        /* IV - Oct 24 2002: end of new code */
 /*          !(n > 0 && n < nreqd &&
             (types[n] == (char) 'm' || types[n] == (char) 'z' ||
              types[n] == (char) 'X' || types[n] == (char) 'N'))) {
-        synterr(csound, Str("illegal no of output args"));
-        if (n > nreqd)
-          n = nreqd;
-      }*/
+             synterr(csound, Str("illegal no of output args"));
+             if (n > nreqd)
+             n = nreqd;
+             }*/
 
 
     while (n--) {                                     /* outargs:  */
       /*        long    tfound_m;*/       /* IV - Oct 31 2002 */
-        s = tp->outlist->arg[n];
-        treqd = types[n];
-        tfound = argtyp2(csound, s);                     /*  found    */
-        /* IV - Oct 31 2002 */
-        /*tfound_m = ST(typemask_tabl)[(unsigned char) tfound];*/
-        /* IV - Sep 1 2002: xoutcod is the same as xincod for input */
-        if (tfound == 'a' && n < 31)
-          tp->xoutcod |= (1 << n);
-        if (tfound == 'S' && n < 31)
-          tp->xoutcod_str |= (1 << n);
-        csound->DebugMsg(csound, "treqd %c, tfound %c", treqd, tfound);
-        /*if (tfound_m & ARGTYP_w)
-          if (ST(lgprevdef)) {
-            synterr(csound, Str("output name previously used, "
-                                "type '%c' must be uniquely defined"), tfound);
-          }*/
-        /* IV - Oct 31 2002: simplified code */
-        /*if (!(tfound_m & ST(typemask_tabl_out)[(unsigned char) treqd])) {
-          synterr(csound, Str("output arg '%s' illegal type"), s);
+      s = tp->outlist->arg[n];
+      treqd = types[n];
+      tfound = argtyp2(csound, s);                     /*  found    */
+      /* IV - Oct 31 2002 */
+      /*tfound_m = ST(typemask_tabl)[(unsigned char) tfound];*/
+      /* IV - Sep 1 2002: xoutcod is the same as xincod for input */
+      if (tfound == 'a' && n < 31)
+        tp->xoutcod |= (1 << n);
+      if (tfound == 'S' && n < 31)
+        tp->xoutcod_str |= (1 << n);
+      csound->DebugMsg(csound, "treqd %c, tfound %c", treqd, tfound);
+      /*if (tfound_m & ARGTYP_w)
+        if (ST(lgprevdef)) {
+        synterr(csound, Str("output name previously used, "
+        "type '%c' must be uniquely defined"), tfound);
         }*/
-      }
+      /* IV - Oct 31 2002: simplified code */
+      /*if (!(tfound_m & ST(typemask_tabl_out)[(unsigned char) treqd])) {
+        synterr(csound, Str("output arg '%s' illegal type"), s);
+        }*/
+    }
 }
 
 /**
  * Create an Opcode (OPTXT) from the AST node given. Called from
  * create_udo and create_instrument.
  */
-OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip) 
+OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 {
-
     TEXT *tp;
     TREE *inargs, *outargs;
     OPTXT *optxt, *retOptxt = NULL;
     char *arg;
     int opnum;
-
     int n;
 
     optxt = (OPTXT *) mcalloc(csound, (int32)sizeof(OPTXT));
@@ -354,8 +358,10 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
     case T_OPCODE:
     case T_OPCODE0:
     case S_ASSIGN:
-//          csound->Message(csound,
-//              "create_opcode: Found node for opcode %s\n", root->value->lexeme);
+      if (PARSER_DEBUG)
+        csound->Message(csound,
+                        "create_opcode: Found node for opcode %s\n",
+                        root->value->lexeme);
 
       opnum = find_opcode(csound, root->value->lexeme);
 
@@ -402,7 +408,7 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
         }
 
         /* update_lclcount(csound, ip, root->right); */
-        
+
         argcount = 0;
 
         /* OUTARGS */
@@ -418,19 +424,19 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
           } else {
             lgbuild(csound, arg);
           }
-          
+
         }
       }
       /* update_lclcount(csound, ip, root->left); */
 
-      
+
       /* VERIFY ARG LISTS MATCH OPCODE EXPECTED TYPES */
 
       {
         OENTRY *ep = csound->opcodlst + tp->opnum;
 
-        csound->Message(csound, "Opcode InTypes: %s\n", ep->intypes);
-        csound->Message(csound, "Opcode OutTypes: %s\n", ep->outypes);
+        //        csound->Message(csound, "Opcode InTypes: %s\n", ep->intypes);
+        //        csound->Message(csound, "Opcode OutTypes: %s\n", ep->outypes);
 
         set_xincod(csound, tp, ep);
         set_xoutcod(csound, tp, ep);
@@ -449,9 +455,9 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
           tp->pftype = tp->intype;
         }
 
-        csound->Message(csound,
-                        Str("create_opcode[%s]: opnum for opcode: %d\n"),
-                        root->value->lexeme, opnum);
+        //        csound->Message(csound,
+        //                        Str("create_opcode[%s]: opnum for opcode: %d\n"),
+        //                        root->value->lexeme, opnum);
       }
       break;
     default:
@@ -463,7 +469,8 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
 
     if (retOptxt == NULL) {
       retOptxt = optxt;
-    } else {
+    }
+    else {
       append_optxt(retOptxt, optxt);
     }
 
@@ -476,7 +483,7 @@ OPTXT *create_opcode(CSOUND *csound, TREE *root, INSTRTXT *ip)
  * Create a UDO (INSTRTXT) from the AST node given. Called from
  * csound_orc_compile.
  */
-INSTRTXT *create_udo(CSOUND *csound, TREE *root) 
+INSTRTXT *create_udo(CSOUND *csound, TREE *root)
 {
     INSTRTXT *ip = (INSTRTXT *) mcalloc(csound, sizeof(INSTRTXT));
     return ip;
@@ -533,11 +540,11 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root)
 
     while(current != NULL) {
 
-      if(current->type != T_INSTR && current->type != T_UDO) {
+      if (current->type != T_INSTR && current->type != T_UDO) {
 
         /* csound->Message(csound, "In INSTR 0: %s\n", current->value->lexeme); */
 
-        if(current->type == S_ASSIGN
+        if (current->type == S_ASSIGN
            && strcmp(current->value->lexeme, "=.r") == 0) {
 
           MYFLT val = csound->pool[constndx(csound,
@@ -559,10 +566,12 @@ INSTRTXT *create_instrument0(CSOUND *csound, TREE *root)
             csound->tran_ksmps = val;
           } else if (current->left->type == T_NCHNLS) {
             csound->tran_nchnls = current->right->value->value;
-            csound->Message(csound, "SETTING NCHNLS: %d\n", csound->tran_nchnls);
+          } else if (current->left->type == T_NCHNLSI) {
+            csound->tran_nchnlsi = current->right->value->value;
+            /* csound->Message(csound, "SETTING NCHNLS: %d\n", csound->tran_nchnls); */
           }
           /* TODO - Implement 0dbfs constant */
-          /*else if (strcmp(s, "0dbfs") == 0) {*/ 
+          /*else if (strcmp(s, "0dbfs") == 0) {*/
           /* we have set this as reserved in rdorch.c */
           /*csound->tran_0dbfs = constval;
             }*/
@@ -635,7 +644,7 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root)
      * Note2: For now am not checking if root->left is a list (i.e. checking
      * root->left->next is NULL or not to indicate list)
      */
-    if(root->left->type == T_INTGR) { /* numbered instrument */
+    if (root->left->type == T_INTGR) { /* numbered instrument */
       int32 instrNum = (int32)root->left->value->value; /* Not used! */
 
       c = csound->Malloc(csound, 10); /* arbritrarily chosen number of digits */
@@ -646,21 +655,21 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root)
       ip->t.inlist->arg[0] = strsav_string(csound, c);
 
       csound->Free(csound, c);
-    } else if(root->left->type == T_IDENT) { /* named instrument */
+    } else if (root->left->type == T_IDENT) { /* named instrument */
       int32  insno_priority = -1L;
       c = root->left->value->lexeme;
 
       csound->Message(csound, Str("create_instrument: instr name %s\n"), c);
 
-      if (*c == '+') {
+      if (UNLIKELY(*c == '+')) {
         insno_priority--; c++;
       }
       /* IV - Oct 31 2002: some error checking */
-      if (!check_instr_name(c)) {
+      if (UNLIKELY(!check_instr_name(c))) {
         synterr(csound, Str("invalid name for instrument"));
       }
       /* IV - Oct 31 2002: store the name */
-      if (!named_instr_alloc(csound, c, ip, insno_priority)) {
+      if (UNLIKELY(!named_instr_alloc(csound, c, ip, insno_priority))) {
         synterr(csound, Str("instr %s redefined"), c);
       }
       ip->insname = c;  /* IV - Nov 10 2002: also in INSTRTXT */
@@ -670,7 +679,7 @@ INSTRTXT *create_instrument(CSOUND *csound, TREE *root)
 
     current = statements;
 
-    while(current != NULL) {
+    while (current != NULL) {
         OPTXT * optxt = create_opcode(csound, current, ip);
 
         op->nxtop = optxt;
@@ -699,7 +708,7 @@ void close_instrument(CSOUND *csound, INSTRTXT * ip)
 
     current = (OPTXT *)ip;
 
-    while(current->nxtop != NULL) {
+    while (current->nxtop != NULL) {
         current = current->nxtop;
     }
 
@@ -802,12 +811,12 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
         i_incnt++; *otypes++ = *types;
         break;
       default:
-        synterr(csound, "invalid input type for opcode %s", inm->name);
+        synterr(csound, Str("invalid input type for opcode %s"), inm->name);
         err++; i--;
       }
       i++; types++;
       if (i > OPCODENUMOUTS_MAX) {
-        synterr(csound, "too many input args for opcode %s", inm->name);
+        synterr(csound, Str("too many input args for opcode %s"), inm->name);
         csound->LongJmp(csound, 1);
       }
     }
@@ -822,7 +831,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       types++;                  /* no output args */
     while (*types) {
       if (i >= OPCODENUMOUTS_MAX) {
-        synterr(csound, "too many output args for opcode %s", inm->name);
+        synterr(csound, Str("too many output args for opcode %s"), inm->name);
         csound->LongJmp(csound, 1);
       }
       switch (*types) {
@@ -838,7 +847,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
         i_outcnt++; *otypes++ = *types;
         break;
       default:
-        synterr(csound, "invalid output type for opcode %s", inm->name);
+        synterr(csound, Str("invalid output type for opcode %s"), inm->name);
         err++; i--;
       }
       i++; types++;
@@ -905,7 +914,7 @@ static int pnum(char *s)        /* check a char string for pnum format  */
 void insert_instrtxt(CSOUND *csound, INSTRTXT *instrtxt, int32 instrNum) {
     int i;
 
-     if (instrNum > csound->maxinsno) {
+    if (UNLIKELY(instrNum > csound->maxinsno)) {
         int old_maxinsno = csound->maxinsno;
 
         /* expand */
@@ -922,7 +931,7 @@ void insert_instrtxt(CSOUND *csound, INSTRTXT *instrtxt, int32 instrNum) {
         }
     }
 
-    if (csound->instrtxtp[instrNum] != NULL) {
+    if (UNLIKELY(csound->instrtxtp[instrNum] != NULL)) {
         synterr(csound, Str("instr %ld redefined"), instrNum);
         /* err++; continue; */
     }
@@ -932,14 +941,14 @@ void insert_instrtxt(CSOUND *csound, INSTRTXT *instrtxt, int32 instrNum) {
 
 OPCODINFO *find_opcode_info(CSOUND *csound, char *opname) {
     OPCODINFO *opinfo = csound->opcodeInfo;
-    if(opinfo == NULL) {
-        csound->Message(csound, "!!! csound->opcodeInfo is NULL !!!\n");
+    if (UNLIKELY(opinfo == NULL)) {
+      csound->Message(csound, Str("!!! csound->opcodeInfo is NULL !!!\n"));
         return NULL;
     }
 
-    while(opinfo != NULL) {
+    while (opinfo != NULL) {
         csound->Message(csound, "%s : %s\n", opinfo->name, opname);
-        if(strcmp(opinfo->name, opname) == 0) {
+        if (UNLIKELY(strcmp(opinfo->name, opname) == 0)) {
             return opinfo;
         }
     }
@@ -951,7 +960,7 @@ OPCODINFO *find_opcode_info(CSOUND *csound, char *opname) {
  * Compile the given TREE node into structs for Csound to use
  */
 void csound_orc_compile(CSOUND *csound, TREE *root) {
-    csound->Message(csound, "Begin Compiling AST (Currently Implementing)\n");
+    //    csound->Message(csound, "Begin Compiling AST (Currently Implementing)\n");
 
     OPARMS      *O = csound->oparms;
     INSTRTXT    *instrtxt = NULL;
@@ -994,14 +1003,15 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     prvinstxt = prvinstxt->nxtinstxt = instr0;
     insert_instrtxt(csound, instr0, 0);
 
-    while(current != NULL) {
+    while (current != NULL) {
 
-        switch(current->type) {
+        switch (current->type) {
+            case T_INIT:
             case S_ASSIGN:
-                csound->Message(csound, "Assignment found\n");
+                /* csound->Message(csound, "Assignment found\n"); */
                 break;
             case T_INSTR:
-                csound->Message(csound, "Instrument found\n");
+                /* csound->Message(csound, "Instrument found\n"); */
 
                 resetouts(csound); /* reset #out counts */
                 lblclear(csound); /* restart labelist  */
@@ -1013,17 +1023,31 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
                 /* Handle Inserting into CSOUND here by checking id's (name or
                  * numbered) and using new insert_instrtxt?
                  */
-
+                printf("Starting to install instruments\n");
                 /* Temporarily using the following code */
-                    if(current->left->type == T_INTGR) { /* numbered instrument */
-                        int32 instrNum = (int32)current->left->value->value;
+                if (current->left->type == T_INTGR) { /* numbered instrument */
+                  int32 instrNum = (int32)current->left->value->value;
 
-                        insert_instrtxt(csound, instrtxt, instrNum);
+                  insert_instrtxt(csound, instrtxt, instrNum);
+                }
+                else if (current->left->type == T_INTLIST) {
+                  TREE *p =  current->left;
+                  printf("intlist case:\n");
+                  while (p) {
+                    print_tree(csound, p);
+                    if (p->left)
+                    insert_instrtxt(csound, instrtxt, p->left->value->value);
+                    else {
+                      insert_instrtxt(csound, instrtxt, p->value->value);
+                      break;
                     }
+                    p = p->right;
+                  }
+                }
 
                 break;
             case T_UDO:
-                csound->Message(csound, "UDO found\n");
+                /* csound->Message(csound, "UDO found\n"); */
 
                 resetouts(csound); /* reset #out counts */
                 lblclear(csound); /* restart labelist  */
@@ -1034,16 +1058,17 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
 
                 opname = current->left->value->lexeme;
 
-                csound->Message(csound,
-                    "Searching for OPCODINFO for opname: %s\n", opname);
+                /* csound->Message(csound, */
+                /*     "Searching for OPCODINFO for opname: %s\n", opname); */
 
                 OPCODINFO *opinfo = find_opcode_info(csound, opname);
 
-                if(opinfo == NULL) {
+                if (UNLIKELY(opinfo == NULL)) {
                     csound->Message(csound,
                         "ERROR: Could not find OPCODINFO for opname: %s\n",
                         opname);
-                } else {
+                }
+                else {
                     opinfo->ip = instrtxt;
                     instrtxt->insname = (char*)mmalloc(csound, 1+strlen(opname));
                     strcpy(instrtxt->insname, opname);
@@ -1056,8 +1081,8 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
 
                 break;
             default:
-                csound->Message(csound, "Unknown TREE node of type %d found in root.\n", current->type);
-                print_tree(csound, current);
+              csound->Message(csound, Str("Unknown TREE node of type %d found in root.\n"), current->type);
+                if (PARSER_DEBUG) print_tree(csound, current);
         }
 
         current = current->next;
@@ -1073,7 +1098,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
       /* IV - Oct 31 2002: now add user defined opcodes */
       while (inm) {
         /* we may need to expand the instrument array */
-        if (++num > csound->maxopcno) {
+        if (UNLIKELY(++num > csound->maxopcno)) {
           int i;
           i = (csound->maxopcno > 0 ? csound->maxopcno : csound->maxinsno);
           csound->maxopcno = i + MAXINSNO;
@@ -1085,7 +1110,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
         }
         inm->instno = num;
 
-        csound->Message(csound, "UDO INSTR NUM: %d\n", num);
+        /* csound->Message(csound, "UDO INSTR NUM: %d\n", num); */
 
         csound->instrtxtp[num] = inm->ip;
         inm = inm->prv;
@@ -1111,14 +1136,15 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
       char      err_msg[128];
       sprintf(err_msg, "sr = %.7g, kr = %.7g, ksmps = %.7g\nerror:",
                        p->tran_sr, p->tran_kr, p->tran_ksmps);
-      if (p->tran_sr <= FL(0.0))
+      if (UNLIKELY(p->tran_sr <= FL(0.0)))
         synterr(p, Str("%s invalid sample rate"), err_msg);
-      if (p->tran_kr <= FL(0.0))
+      if (UNLIKELY(p->tran_kr <= FL(0.0)))
         synterr(p, Str("%s invalid control rate"), err_msg);
-      else if (p->tran_ksmps < FL(0.75) ||
-               FLOAT_COMPARE(p->tran_ksmps, MYFLT2LRND(p->tran_ksmps)))
+      else if (UNLIKELY(p->tran_ksmps < FL(0.75) ||
+                        FLOAT_COMPARE(p->tran_ksmps, MYFLT2LRND(p->tran_ksmps))))
         synterr(p, Str("%s invalid ksmps value"), err_msg);
-      else if (FLOAT_COMPARE(p->tran_sr, (double) p->tran_kr * p->tran_ksmps))
+      else if (UNLIKELY(FLOAT_COMPARE(p->tran_sr,
+                                      (double) p->tran_kr * p->tran_ksmps)))
         synterr(p, Str("%s inconsistent sr, kr, ksmps"), err_msg);
     }
 
@@ -1129,16 +1155,16 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
       int thread, opnum = bp->t.opnum;
       if (opnum == ENDIN) break;
       if (opnum == LABEL) continue;
-      if ((thread = csound->opcodlst[opnum].thread) & 06 ||
-          (!thread && bp->t.pftype != 'b'))
+      if (UNLIKELY((thread = csound->opcodlst[opnum].thread) & 06 ||
+                   (!thread && bp->t.pftype != 'b')))
         synterr(csound, Str("perf-pass statements illegal in header blk\n"));
     }
-    if (csound->synterrcnt) {
+    if (UNLIKELY(csound->synterrcnt)) {
       print_opcodedir_warning(csound);
       csound->Die(csound, Str("%d syntax errors in orchestra.  "
                               "compilation invalid\n"), csound->synterrcnt);
     }
-    if (O->odebug) {
+    if (UNLIKELY(O->odebug)) {
       int32  n;
       MYFLT *p;
       csound->Message(csound, "poolcount = %ld, strpool_cnt = %ld\n",
@@ -1186,7 +1212,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     ip = &(csound->instxtanchor);
     while ((ip = ip->nxtinstxt) != NULL)        /* add all other entries */
       insprep(csound, ip);                      /*   as combined offsets */
-    if (O->odebug) {
+    if (UNLIKELY(O->odebug)) {
       int *p = csound->argoffspace;
       csound->Message(csound, "argoff array:\n");
       do {
@@ -1194,7 +1220,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
       } while (p < ST(argofflim));
       csound->Message(csound, "\n");
     }
-    if (ST(nxtargoffp) != ST(argofflim))
+    if (UNLIKELY(ST(nxtargoffp) != ST(argofflim)))
       csoundDie(csound, Str("inconsistent argoff sumcount"));
 
     ip = &(csound->instxtanchor);               /* set the OPARMS values */
@@ -1217,7 +1243,7 @@ void csound_orc_compile(CSOUND *csound, TREE *root) {
     ST(constTbl) = NULL;
     /* End code from otran */
 
-    csound->Message(csound, "End Compiling AST\n");
+    /* csound->Message(csound, "End Compiling AST\n"); */
 
 }
 
@@ -1313,7 +1339,7 @@ static void insprep(CSOUND *csound, INSTRTXT *tp)
                 mrealloc(csound, larg, csound->ngotos * sizeof(LBLARG));
               largp = &larg[oldn];
             }
-            if (O->odebug)
+            if (UNLIKELY(O->odebug))
               csound->Message(csound, "\t***lbl");  /* if arg is label,  */
             largp->lbltxt = *argp;
             largp->ndxp = ndxp;                     /*  defer till later */
@@ -1322,12 +1348,12 @@ static void insprep(CSOUND *csound, INSTRTXT *tp)
           else {
             char *s = *argp;
             indx = plgndx(csound, s);
-            if (O->odebug) csound->Message(csound, "\t%d", indx);
+            if (UNLIKELY(O->odebug)) csound->Message(csound, "\t%d", indx);
             *ndxp = indx;
           }
         }
       }
-      if (O->odebug) csound->Message(csound, "\n");
+      if (UNLIKELY(O->odebug)) csound->Message(csound, "\n");
     }
  nxt:
     while (--largp >= larg) {                   /* resolve the lbl refs */
@@ -1402,7 +1428,7 @@ static int strconstndx(CSOUND *csound, const char *s)
 
     /* check syntax */
     cnt = (int) strlen(s);
-    if (cnt < 2 || *s != '"' || s[cnt - 1] != '"') {
+    if (UNLIKELY(cnt < 2 || *s != '"' || s[cnt - 1] != '"')) {
       synterr(csound, Str("string syntax '%s'"), s);
       return 0;
     }
@@ -1452,7 +1478,7 @@ static int constndx(CSOUND *csound, const char *s)
       char            *tmp = (char*) s;
       tmpVal = (MYFLT) strtod(s, &tmp);
       newval = tmpVal;
-      if (tmp == s || *tmp != (char) 0) {
+      if (UNLIKELY(tmp == s || *tmp != (char) 0)) {
         synterr(csound, Str("numeric syntax '%s'"), s);
         return 0;
       }
@@ -1478,7 +1504,7 @@ static int constndx(CSOUND *csound, const char *s)
     n = ST(poolcount)++;
     if (n >= ST(nconsts)) {
       ST(nconsts) = ((ST(nconsts) + (ST(nconsts) >> 3)) | (NCONSTS - 1)) + 1;
-      if (csound->oparms->msglevel)
+      if (UNLIKELY(csound->oparms->msglevel))
         csound->Message(csound, Str("extending Floating pool to %d\n"),
                                 ST(nconsts));
       csound->pool = (MYFLT*) mrealloc(csound, csound->pool, ST(nconsts)
@@ -1517,7 +1543,7 @@ static void gblnamset(CSOUND *csound, char *s)
     if (p != NULL)                              /* if name is there     */
       return;                                   /*    return            */
     p = (NAME*) malloc(sizeof(NAME));
-    if (p == NULL)
+    if (UNLIKELY(p == NULL))
       csound->Die(csound, Str("gblnamset(): memory allocation failure"));
     p->namep = s;                               /* else record newname  */
     p->nxt = ST(gblNames)[h];
@@ -1545,7 +1571,7 @@ static NAME *lclnamset(CSOUND *csound, char *s)
     if (p != NULL)                              /* if name is there     */
       return p;                                 /*    return ptr        */
     p = (NAME*) malloc(sizeof(NAME));
-    if (p == NULL)
+    if (UNLIKELY(p == NULL))
       csound->Die(csound, Str("lclnamset(): memory allocation failure"));
     p->namep = s;                               /* else record newname  */
     p->nxt = ST(lclNames)[h];
@@ -1570,7 +1596,7 @@ static int gbloffndx(CSOUND *csound, char *s)
     NAME          *p = ST(gblNames)[h];
 
     for ( ; p != NULL && sCmp(p->namep, s); p = p->nxt);
-    if (p == NULL)
+    if (UNLIKELY(p == NULL))
       csoundDie(csound, Str("unexpected global name"));
     switch (p->type) {
       case ATYPE: return (ST(gblfixed) + p->count);
@@ -1722,7 +1748,7 @@ char argtyp2(CSOUND *csound, char *s)
 {                       /* find arg type:  d, w, a, k, i, c, p, r, S, B, b */
     char c = *s;        /*   also set lgprevdef if !c && !p && !S */
 
-    csound->Message(csound, "\nArgtyp2: received %s\n", s);
+    /* csound->Message(csound, "\nArgtyp2: received %s\n", s); */
 
     /*trap this before parsing for a number! */
     /* two situations: defined at header level: 0dbfs = 1.0
