@@ -66,6 +66,7 @@
 /* outarg types include:
                 m       multiple out aargs
                 z       multiple out kargs
+                I       multiple out irate (not implemented yet)
                 s       arate or krate scalar
                 X       multiple args (a, k, or i-rate)     IV - Sep 1 2002
                 N       multiple args (a, k, i, or S-rate)
@@ -312,7 +313,7 @@ OENTRY opcodlst_1[] = {
 { "envlpx", S(ENVLPX),  7,      "s","xiiiiiio", evxset, knvlpx, envlpx  },
 { "envlpxr", S(ENVLPR), 7,      "s","xiiiiioo", evrset, knvlpxr,envlpxr },
 { "phasor", S(PHSOR),   7,      "s",    "xo",   phsset, kphsor, phsor   },
-{ "ephasor", S(EPHSOR),   5,      "s",    "xko",  ephsset, NULL, ephsor   },
+{ "ephasor", S(EPHSOR),   5,    "ss",    "xko",  ephsset, NULL, ephsor   },
 { "table",  0xffff                                                      },
 { "tablei", 0xffff                                                      },
 { "table3", 0xffff                                                      },
@@ -360,6 +361,7 @@ OENTRY opcodlst_1[] = {
 { "resonx", S(RESONX),  5,      "a",    "akkooo", rsnsetx, NULL, resonx },
 { "areson", S(RESON),   5,      "a",    "akkoo",rsnset, NULL,   areson  },
 { "lpread", S(LPREAD),  3,      "kkkk", "kToo", lprdset,lpread          },
+{ "lpform", S(LPFORM),  3,      "kk", "k",     lpformantset,lpformant   },
 { "lpreson",S(LPRESON), 5,      "a",    "a",    lprsnset,NULL,  lpreson },
 { "lpfreson",S(LPFRESON),5,     "a",    "ak",   lpfrsnset,NULL, lpfreson},
 { "lpslot"  ,  S(LPSLOT),  1,   "",     "i",    lpslotset, NULL, NULL   },
@@ -498,6 +500,7 @@ OENTRY opcodlst_1[] = {
 { "filelen", S(SNDINFO), 1,     "i",    "Tp",   filelen, NULL, NULL        },
 { "filenchnls", S(SNDINFO), 1,  "i",    "Tp",   filenchnls, NULL, NULL     },
 { "filesr", S(SNDINFO),  1,     "i",    "Tp",   filesr, NULL, NULL         },
+{ "filebit", S(SNDINFO),  1,     "i",    "Tp",   filebit, NULL, NULL         },
 { "filepeak", S(SNDINFOPEAK), 1, "i",   "To",   filepeak, NULL, NULL       },
 /*  { "nlalp", S(NLALP),     5,     "a",    "akkoo", nlalp_set, NULL, nlalp }, */
 /* Robin Whittle */
