@@ -139,12 +139,12 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
         S_incnt++; *otypes++ = *types;
         break;
       default:
-        synterr(csound, "invalid input type for opcode %s", inm->name);
+        synterr(csound, Str("invalid input type for opcode %s"), inm->name);
         err++; i--;
       }
       i++; types++;
       if (UNLIKELY(i > OPCODENUMOUTS_MAX)) {
-        synterr(csound, "too many input args for opcode %s", inm->name);
+        synterr(csound, Str("too many input args for opcode %s"), inm->name);
         csound->LongJmp(csound, 1);
       }
     }
@@ -159,7 +159,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       types++;                  /* no output args */
     while (*types) {
       if (UNLIKELY(i >= OPCODENUMOUTS_MAX)) {
-        synterr(csound, "too many output args for opcode %s", inm->name);
+        synterr(csound, Str("too many output args for opcode %s"), inm->name);
         csound->LongJmp(csound, 1);
       }
       switch (*types) {
@@ -178,7 +178,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
         S_outcnt++; *otypes++ = *types;
         break;
       default:
-        synterr(csound, "invalid output type for opcode %s", inm->name);
+        synterr(csound, Str("invalid output type for opcode %s"), inm->name);
         err++; i--;
       }
       i++; types++;
@@ -268,6 +268,7 @@ void otran(CSOUND *csound)
     gblnamset(csound, "kr");
     gblnamset(csound, "ksmps");
     gblnamset(csound, "nchnls");
+    gblnamset(csound, "nchnls_i");
     gblnamset(csound, "0dbfs"); /* no commandline override for that! */
     gblnamset(csound, "$sr");   /* incl command-line overrides */
     gblnamset(csound, "$kr");
@@ -342,7 +343,7 @@ void otran(CSOUND *csound)
                   }
                   /* IV - Oct 31 2002: store the name */
                   if (UNLIKELY(!named_instr_alloc(csound, c, ip, insno_priority))) {
-                    synterr(csound, "instr %s redefined", c);
+                    synterr(csound, Str("instr %s redefined"), c);
                     err++; continue;
                   }
                   ip->insname = c;  /* IV - Nov 10 2002: also in INSTRTXT */
@@ -494,6 +495,8 @@ void otran(CSOUND *csound)
                   csound->tran_ksmps = constval;
                 else if (strcmp(s, "nchnls") == 0)
                   csound->tran_nchnls = (int) constval;
+                else if (strcmp(s, "nchnls_i") == 0)
+                  csound->tran_nchnlsi = (int) constval;
                 /* we have set this as reserved in rdorch.c */
                 else if (strcmp(s, "0dbfs") == 0)
                   csound->tran_0dbfs = constval;
@@ -1205,13 +1208,15 @@ void oload(CSOUND *p)
       inoffp = ttp->inoffs;             /* to find sr.. assigns */
       if (outoffp->count == 1 && inoffp->count == 1) {
         int rindex = (int) outoffp->indx[0] - (int) p->poolcount;
-        if (rindex > 0 && rindex <= 5) {
+        if (rindex > 0 && rindex <= 6) {
           MYFLT conval = p->pool[inoffp->indx[0] - 1];
           switch (rindex) {
             case 1:  p->esr = conval;   break;  /* & use those values */
             case 2:  p->ekr = conval;   break;  /*  to set params now */
             case 3:  p->ksmps = (int) ((ensmps = conval) + FL(0.5)); break;
             case 4:  p->nchnls = (int) (conval + FL(0.5));  break;
+            case 5:  p->inchnls = (int) (conval + FL(0.5));  break;
+            case 6:
             default: p->e0dbfs = conval; break;
           }
         }
@@ -1382,7 +1387,7 @@ void oload(CSOUND *p)
     reverbinit(p);
     dbfs_init(p, p->e0dbfs);
     p->nspout = p->ksmps * p->nchnls;  /* alloc spin & spout */
-    p->nspin = p->nspout;
+    p->nspin = p->ksmps * p->nchnls_i; /* JPff: in preparation */
     p->spin  = (MYFLT *) mcalloc(p, p->nspin * sizeof(MYFLT));
     p->spout = (MYFLT *) mcalloc(p, p->nspout * sizeof(MYFLT));
     /* chk consistency one more time (FIXME: needed ?) */
