@@ -88,9 +88,6 @@ typedef struct {
     int32    lenmax /* = LENMAX */;  /* Length of input line buffer  */
     char    *ortext;
     char    **linadr;               /* adr of each line in text     */
-#if 0   /* unused */
-    int     *srclin;                /* text no. of expanded lines   */
-#endif
     int     curline;                /* current line being examined  */
     char    *collectbuf;            /* splitline collect buffer     */
     char    **group;                /* splitline local storage      */
@@ -165,7 +162,7 @@ static inline void ungetorchar(CSOUND *csound, int c)
     if (LIKELY(ST(str)->unget_cnt < 128))
       ST(str)->unget_buf[ST(str)->unget_cnt++] = (char) c;
     else
-      csoundDie(csound, "ungetorchar(): buffer overflow");
+      csoundDie(csound, Str("ungetorchar(): buffer overflow"));
 }
 
 static int skiporccomment(CSOUND *csound)
@@ -340,7 +337,7 @@ void *fopen_path(CSOUND *csound, FILE **fp, char *name, char *basename,
 {
     void *fd;
     int  csftype = (fromScore ? CSFTYPE_SCO_INCLUDE : CSFTYPE_ORC_INCLUDE);
-    
+
                                 /* First try to open name given */
     fd = csound->FileOpen2(csound, fp, CSFILE_STD, name, "rb", NULL,
                                              csftype, 0);
@@ -504,10 +501,6 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
     ST(str)->unget_cnt = 0;
     ortext = mmalloc(csound, ST(orchsiz) + 1);          /* alloc mem spaces */
     ST(linadr) = (char **) mmalloc(csound, (LINMAX + 1) * sizeof(char *));
-#if 0   /* unused */
-    ST(srclin) = (int *) mmalloc(csound, (LINMAX + 1) * sizeof(int));
-    ST(srclin)[1] = 1;
-#endif
     strsav_create(csound);
     lincnt = srccnt = 1;
     cp = ST(linadr)[1] = ortext;
@@ -570,8 +563,7 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
         if (c == '\n') {
           cp--;                                      /* Ignore newline */
           srccnt++;                                  /*    record a fakeline */
-/*        ST(srclin)[++lincnt] = 0;     unused  */
-/*        ST(linadr)[lincnt] = cp; */
+          lincnt++;
         }
         else {
           *cp++ = c;
@@ -601,10 +593,6 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
           linmax += 100;
           ST(linadr) = (char**) mrealloc(csound, ST(linadr), (linmax + 1)
                                                              * sizeof(char*));
-#if 0   /* unused */
-          ST(srclin) = (int*) mrealloc(csound, ST(srclin), (linmax + 1)
-                                                           * sizeof(int));
-#endif
         }
   /*    ST(srclin)[lincnt] = srccnt;    unused  */
         ST(linadr)[lincnt] = cp;            /* record the adrs */
@@ -612,43 +600,51 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
       else if (c == '#' && ST(linepos) == 0 && !heredoc) {
         /* Start Macro definition */
         /* also deal with #include here */
-        char  mname[100], *preprocName;
+        char  *mname, *preprocName;
+        int mlen = 40;
         int   i, cnt;
+        mname = (char  *)malloc(mlen);
         cp--;
  parsePreproc:
         preprocName = NULL;
         i = 0;
         cnt = 0;
         mname[cnt++] = '#';
+        if (cnt==mlen)
+          mname = (char *)realloc(mname, mlen+=40);
         do {
           c = getorchar(csound);
           if (UNLIKELY(c == EOF))
             break;
           mname[cnt++] = c;
-        } while ((c == ' ' || c == '\t') && cnt < 99);
+          if (cnt==mlen)
+            mname = (char *)realloc(mname, mlen+=40);
+        } while ((c == ' ' || c == '\t'));
         mname[cnt] = '\0';
-        if (c == EOF || c == '\n' || cnt >= 99)
+        if (c == EOF || c == '\n')
           goto unknownPreproc;
         preprocName = &(mname[cnt - 1]);
-        do {
+        while (1) {
           c = getorchar(csound);
           if (c == EOF || !(isalnum(c) || c == '_'))
             break;
           mname[cnt++] = c;
-        } while (cnt < 99);
+          if (cnt==mlen)
+            mname = (char *)realloc(mname, mlen+=40);
+        }
         mname[cnt] = '\0';
-        if (cnt >= 99)
-          goto unknownPreproc;
         if (strcmp(preprocName, "define") == 0 &&
             !(ST(ifdefStack) != NULL && ST(ifdefStack)->isSkip)) {
           MACRO *mm = (MACRO*) mmalloc(csound, sizeof(MACRO));
           int   arg = 0;
-          int   size = 100;
+          int   size = 40;
           mm->margs = MARGS;    /* Initial size */
           while (isspace((c = getorchar(csound))))
             ;
           while (isNameChar(c, i)) {
             mname[i++] = c;
+            if (i==mlen)
+              mname = (char *)realloc(mname, mlen+=40);
             c = getorchar(csound);
           }
           mname[i] = '\0';
@@ -666,6 +662,8 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
               i = 0;
               while (isNameChar(c, i)) {
                 mname[i++] = c;
+                if (i==mlen)
+                  mname = (char *)realloc(mname, mlen+=40);
                 c = getorchar(csound);
               }
               mname[i] = '\0';
@@ -718,9 +716,12 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
             c = getorchar(csound);
           delim = c;
           i = 0;
-          while ((c = getorchar_noeof(csound)) != delim)
+          while ((c = getorchar_noeof(csound)) != delim) {
             mname[i++] = c;
-          mname[i] = '\0';
+            if (i==mlen)
+              mname = (char *)realloc(mname, mlen+=40);
+          }
+           mname[i] = '\0';
           do {
             c = getorchar(csound);
           } while (c != EOF && c != '\n');
@@ -762,6 +763,8 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
             ;
           while (isNameChar(c, i)) {
             mname[i++] = c;
+            if (i==mlen)
+              mname = (char *)realloc(mname, mlen+=40);
             c = getorchar(csound);
           }
           mname[i] = '\0';
@@ -828,6 +831,8 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
             ;
           while (isNameChar(c, i)) {
             mname[i++] = c;
+            if (i==mlen)
+              mname = (char *)realloc(mname, mlen+=40);
             c = getorchar(csound);
           }
           mname[i] = '\0';
@@ -866,6 +871,7 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
           else
             lexerr(csound, Str("Unknown # option: '%s'"), preprocName);
         }
+        free(mname);
       }
       else if (c == '$' && !heredoc) {
         char      name[100];
@@ -969,7 +975,9 @@ void rdorchfile(CSOUND *csound)     /* read entire orch file into txt space */
       *cp++ = '\n';                         /*    add one           */
     else --lincnt;
     ST(linadr)[lincnt+1] = NULL;            /* terminate the adrs list */
-    csound->Message(csound,Str("%d lines read\n"),lincnt);
+#ifdef BETA
+    csound->Message(csound,Str("%d (%d) lines read\n"),lincnt, srccnt);
+#endif
     if (ST(fd) != NULL) {
       csound->FileClose(csound, ST(fd));    /* close the file       */
       ST(fd) = NULL;
@@ -1129,7 +1137,13 @@ static int splitline(CSOUND *csound)
           extend_group(csound);
         grpp = ST(group)[grpcnt++] = cp;
         *cp++ = c;                          /*  cpy to nxt quote */
-        while ((*cp++ = c = *lp++) != '"' && c != '\n');
+       do {
+          c = *lp++;
+          if (c=='\\') {                    /* Deal with \" case */
+            c = *lp++;
+          }
+          *cp++ = c;
+       } while (c != '"' && c != '\n');
         if (c == '\n')
           synterrp(csound, lp - 1, Str("unmatched quotes"));
         collecting = 1;                     /*   & resume chking */
@@ -1458,9 +1472,6 @@ TEXT *getoptxt(CSOUND *csound, int *init)
       if (!(ST(grpcnt) = splitline(csound))) {  /*    attack next line    */
         /* end of orchestra, clean up */
         mfree(csound, ST(linadr));      ST(linadr) = NULL;
-#if 0   /* unused */
-        mfree(csound, ST(srclin));      ST(srclin) = NULL;
-#endif
         mfree(csound, ST(ortext));      ST(ortext) = NULL;
         mfree(csound, ST(collectbuf));  ST(collectbuf) = NULL;
         mfree(csound, ST(group));       ST(group) = NULL;
@@ -1811,7 +1822,8 @@ TEXT *getoptxt(CSOUND *csound, int *init)
             synterr(csound, Str("missing or extra arg"));
         }       /* IV - Sep 1 2002: added 'M' */
         else if (UNLIKELY(treqd != 'm' && treqd != 'z' && treqd != 'y' &&
-                          treqd != 'Z' && treqd != 'M' && treqd != 'N')) /* else any no */
+                          treqd != 'Z' && treqd != 'M' &&
+                          treqd != 'N')) /* else any no */
           synterr(csound, Str("too many input args"));
       }
       else if (incnt < nreqd) {         /*  or set defaults: */
@@ -1880,7 +1892,8 @@ TEXT *getoptxt(CSOUND *csound, int *init)
         tfound = argtyp(csound, s);     /* else get arg type */
         /* IV - Oct 31 2002 */
         tfound_m = ST(typemask_tabl)[(unsigned char) tfound];
-        if (UNLIKELY(!(tfound_m & (ARGTYP_c|ARGTYP_p)) && !ST(lgprevdef) && *s != '"')) {
+        if (UNLIKELY(!(tfound_m & (ARGTYP_c|ARGTYP_p)) &&
+                     !ST(lgprevdef) && *s != '"')) {
           synterr(csound, Str("input arg '%s' used before defined"), s);
         }
         csound->DebugMsg(csound, "treqd %c, tfound %c", treqd, tfound);
@@ -1893,6 +1906,9 @@ TEXT *getoptxt(CSOUND *csound, int *init)
         if (!(tfound_m & ST(typemask_tabl_in)[(unsigned char) treqd])) {
           /* check for exceptional types */
           switch (treqd) {
+          case 'I':
+            treqd_m = ARGTYP_i;
+            break;
           case 'Z':                             /* indef kakaka ... */
             if (UNLIKELY(!(tfound_m & (n & 1 ? ARGTYP_a : ARGTYP_ipcrk))))
               intyperr(csound, n, tfound, treqd);
@@ -1968,10 +1984,10 @@ TEXT *getoptxt(CSOUND *csound, int *init)
       }
       if (nreqd < 0)    /* for other opcodes */
         nreqd = strlen(types = ep->outypes);
-      if (UNLIKELY((n != nreqd) &&               /* IV - Oct 24 2002: end of new code */
+      if (UNLIKELY((n != nreqd) &&      /* IV - Oct 24 2002: end of new code */
           !(n > 0 && n < nreqd &&
-            (types[n] == (char) 'm' || types[n] == (char) 'z' ||
-             types[n] == (char) 'X' || types[n] == (char) 'N')))) {
+            (types[n] == 'm' || types[n] == 'z' || types[n] == 'I' ||
+             types[n] == 'X' || types[n] ==  'N')))) {
         synterr(csound, Str("illegal no of output args"));
         if (n > nreqd)
           n = nreqd;
@@ -2080,7 +2096,7 @@ char argtyp(CSOUND *csound, char *s)
       return('S');                              /* quoted String */
     ST(lgprevdef) = lgexist(csound, s);               /* (lgprev) */
     if (strcmp(s,"sr") == 0    || strcmp(s,"kr") == 0 ||
-        strcmp(s,"0dbfs") == 0 ||
+        strcmp(s,"0dbfs") == 0 || strcmp(s,"nchnls_i") == 0 || 
         strcmp(s,"ksmps") == 0 || strcmp(s,"nchnls") == 0)
       return('r');                              /* rsvd */
     if (c == 'w')               /* N.B. w NOT YET #TYPE OR GLOBAL */
