@@ -400,7 +400,7 @@ public:
   {
     csoundInputMessage(csound, message);
   }
-  virtual void KeyPress(char c)
+  virtual void KeyPressed(char c)
   {
     csoundKeyPress(csound, c);
   }
@@ -795,10 +795,9 @@ public:
     ((pycbdata *)pydata)->mfunc = NULL;
     delete (pycbdata *)pydata;
     #endif
-    
+
   }
   // Functions for embedding.
-//#ifdef __BUILDING_CSOUND_INTERFACES
   virtual void EnableMessageBuffer(int toStdOut)
   {
     csoundEnableMessageBuffer(csound, toStdOut);
@@ -823,7 +822,14 @@ public:
   {
     csoundDestroyMessageBuffer(csound);
   }
-//#endif
+  virtual void AddSpinSample(int frame, int channel, MYFLT sample)
+  {
+    csoundAddSpinSample(csound, frame, channel, sample);
+  }
+  virtual MYFLT GetSpoutSample(int frame, int channel) const
+  {
+    return csoundGetSpoutSample(csound, frame, channel);
+  }
 };
 
 // thread locks
