@@ -50,8 +50,8 @@ extern "C" {
 #define CSFILE_SND_W    5
 
 #define MAXINSNO  (200)
-#define PMAX      (1000)
-#define VARGMAX   (1001)
+#define PMAX      (1998)
+#define VARGMAX   (1999)
 
 #define ORTXT       h.optext->t
 #define INCOUNT     ORTXT.inlist->count
@@ -440,6 +440,10 @@ extern "C" {
     MYFLT   p3orig;
     /** All p-fields for this event (SSTRCOD: string argument) */
     MYFLT   p[PMAX + 1];
+    union {                   /* To ensure size is same as earlier */
+      MYFLT   *extra;
+      MYFLT   p[2];
+    } c;
   } EVTBLK;
 
   typedef struct {
@@ -689,6 +693,8 @@ extern const uint32_t csPlayScoMask;
    * Contains all function pointers, data, and data pointers required
    * to run one instance of Csound.
    */
+  /* Eventually this will be changed to inchnls -- JPff */
+#define nchnls_i nchnls
   struct CSOUND_ {
     /* Csound API function pointers (320 total) */
     int (*GetVersion)(void);
@@ -738,7 +744,7 @@ extern const uint32_t csPlayScoMask;
     int (*GetMessageLevel)(CSOUND *);
     void (*SetMessageLevel)(CSOUND *, int messageLevel);
     void (*InputMessage)(CSOUND *, const char *message__);
-    void (*KeyPress)(CSOUND *, char c__);
+    void (*KeyPressed)(CSOUND *, char c__);
     void (*SetInputValueCallback)(CSOUND *,
                 void (*inputValueCalback)(CSOUND *, const char *channelName,
                                                     MYFLT *value));
@@ -894,7 +900,7 @@ extern const uint32_t csPlayScoMask;
     int (*RegisterResetCallback)(CSOUND *, void *userData,
                                            int (*func)(CSOUND *, void *));
     void *(*CreateFileHandle)(CSOUND *, void *, int, const char *);
-    /* Do not use FileOpen in new code; it has been replaced by FileOpen2 */ 
+    /* Do not use FileOpen in new code; it has been replaced by FileOpen2 */
     void *(*FileOpen)(CSOUND *,
                       void *, int, const char *, void *, const char *);
     char *(*GetFileName)(void *);
@@ -969,15 +975,24 @@ extern const uint32_t csPlayScoMask;
     void *(*CreateBarrier)(unsigned int max);
     int (*DestroyBarrier)(void *);
     int (*WaitBarrier)(void *);
-    void *(*FileOpen2)(CSOUND *, void *, int, const char *, void *, 
+    void *(*FileOpen2)(CSOUND *, void *, int, const char *, void *,
                       const char *, int, int);
     int (*type2csfiletype)(int type, int encoding);
     MEMFIL *(*ldmemfile2)(CSOUND *, const char *, int);
     void (*NotifyFileOpened)(CSOUND*, const char*, int, int, int);
     int (*sftype2csfiletype)(int type);
     int (*insert_score_event_at_sample)(CSOUND *, EVTBLK *, long);
+    int *(*GetChannelLock)(CSOUND *, const char *name, int type);
+    MEMFIL *(*ldmemfile2withCB)(CSOUND *, const char *, int,
+                                int (*callback)(CSOUND *, MEMFIL *));
+    void (*AddSpinSample)(CSOUND *, int, int, MYFLT);
+    MYFLT (*GetSpoutSample)(CSOUND *, int, int);
+    int (*ChanIKSetValue)(CSOUND *, int channel, MYFLT value);
+    MYFLT (*ChanOKGetValue)(CSOUND *, int channel);
+    int (*ChanIASetSample)(CSOUND *, int channel, int frame, MYFLT sample);
+    MYFLT (*ChanOAGetSample)(CSOUND *, int channel, int frame);
  /* SUBR dummyfn_1; */
-    SUBR dummyfn_2[86];
+    SUBR dummyfn_2[78];
     int           dither_output;
     void          *flgraphGlobals;
     char          *delayederrormessages;
@@ -1038,7 +1053,10 @@ extern const uint32_t csPlayScoMask;
     CsoundRandMTState *csRandState;
     int           randSeed1;
     int           randSeed2;
-    int   dummyint[10];
+    int           memlock;
+    int           floatsize;
+    int           inchnls;      /* Not used yet -- JPff */
+    int   dummyint[7];
     long  dummyint32[10];
     /* ------- private data (not to be used by hosts or externals) ------- */
 #ifdef __BUILDING_LIBCSOUND
@@ -1263,6 +1281,9 @@ extern const uint32_t csPlayScoMask;
     int           orcLineOffset; /* 1 less than 1st orch line in the CSD */
     int           scoLineOffset; /* 1 less than 1st score line in the CSD */
     char*         csdname;       /* original CSD name; do not free() */
+    int           parserUdoflag;
+    int           parserNamedInstrFlag;
+    int           tran_nchnlsi;
 #endif  /* __BUILDING_LIBCSOUND */
   };
 
