@@ -151,7 +151,7 @@ int     linenr(CSOUND *, void *), evxset(CSOUND *, void *);
 int     knvlpx(CSOUND *, void *), envlpx(CSOUND *, void *);
 int     evrset(CSOUND *, void *), knvlpxr(CSOUND *, void *);
 int     envlpxr(CSOUND *, void *), phsset(CSOUND *, void *);
-int     ephsset(CSOUND *, void *), ephsor(CSOUND *, void *);;
+int     ephsset(CSOUND *, void *), ephsor(CSOUND *, void *);
 int     kphsor(CSOUND *, void *), phsor(CSOUND *, void *);
 int     itablew1(CSOUND *, void *), itablegpw1(CSOUND *, void *);
 int     itablemix1(CSOUND *, void *), itablecopy1(CSOUND *, void *);
@@ -197,6 +197,7 @@ int     resonx(CSOUND *, void *), aresonx(CSOUND *, void *);
 int     rsnsetx(CSOUND *, void *), tonex(CSOUND *, void *);
 int     atonex(CSOUND *, void *), tonsetx(CSOUND *, void *);
 int     lprdset(CSOUND *, void *), lpread(CSOUND *, void *);
+int     lpformantset(CSOUND *, void *), lpformant(CSOUND *, void*);
 int     lprsnset(CSOUND *, void *), lpreson(CSOUND *, void *);
 int     lpfrsnset(CSOUND *, void *), lpfreson(CSOUND *, void *);
 int     lpslotset(CSOUND *, void *), lpitpset(CSOUND *, void *);
@@ -369,3 +370,4 @@ int     delete_instr(CSOUND *, void *);
 int     insremot(CSOUND *, void *), insglobal(CSOUND *, void *);
 int     midremot(CSOUND *, void *), midglobal(CSOUND *, void *);
 int     remoteport(CSOUND *, void *);
+int filebit(CSOUND *, void *);
