@@ -476,14 +476,14 @@ static void sortEventLists(CSOUND *csound)
       nbytes = (size_t) MF(nEvents) * sizeof(midiEvent_t);
       if (((size_t) MF(nTempo) * sizeof(tempoEvent_t)) > nbytes)
         nbytes = (size_t) MF(nTempo) * sizeof(tempoEvent_t);
-      tmp = csound->Malloc(csound, nbytes);
+      tmp = malloc(nbytes);
       if (MF(nEvents) > 1)
         midiEvent_sort(MF(eventList), (midiEvent_t *) tmp,
                        (size_t) MF(nEvents));
       if (MF(nTempo) > 1)
         tempoEvent_sort(MF(tempoList), (tempoEvent_t *) tmp,
                         (size_t) MF(nTempo));
-      csound->Free(csound, tmp);
+      free(tmp);
     }
     if (MF(timeCode) > 0.0) {
       /* tick values are in fractions of a beat */
