@@ -44,6 +44,7 @@ typedef struct devparams_ {
     float   srate;
     int     nchns;
     int     isNInterleaved;
+    AudioDeviceIOProcID     procID;
 } DEVPARAMS;
 
 /* module interface functions */
@@ -78,8 +79,8 @@ int csoundModuleCreate(CSOUND *csound)
                                    NULL);
 
     if (csound->oparms->msglevel & 0x400)
-      p->Message(csound, "CoreAudio real-time audio module for Csound\n"
-                 "by Victor Lazzarini\n");
+      p->Message(csound, Str("CoreAudio real-time audio module for Csound\n"
+			     "by Victor Lazzarini\n"));
     return 0;
 }
 
@@ -211,7 +212,7 @@ int coreaudio_open(CSOUND *csound, const csRtAudioParams * parm,
     p->DestroyGlobalVariable(csound, "::cabuffnos");
 
     vpt = (int *) (p->QueryGlobalVariable(csound, "::cainterleaved"));
-    
+
     /*
      if (vpt != NULL)
       dev->isNInterleaved = *vpt;
@@ -306,7 +307,7 @@ int coreaudio_open(CSOUND *csound, const csRtAudioParams * parm,
     psize = sizeof(AudioStreamBasicDescription);
     AudioDeviceGetProperty(dev->dev, 0, false,
                            kAudioDevicePropertyStreamFormat, &psize, &format);
-     
+
     dev->isNInterleaved = 0;
 
     dev->format.mSampleRate = dev->srate;
@@ -349,8 +350,8 @@ int coreaudio_open(CSOUND *csound, const csRtAudioParams * parm,
 
       p->Message(csound,
                  Str("CoreAudio module: sr set to %d with %d audio channels \n"),
-                 (int) dev->srate, (int) dev->nchns);      
-    }    
+                 (int) dev->srate, (int) dev->nchns);
+    }
 
     dev->outbuffs = (float **) malloc(sizeof(float *) * dev->buffnos);
     dev->inbuffs = (float **) malloc(sizeof(float *) * dev->buffnos);
@@ -368,7 +369,8 @@ int coreaudio_open(CSOUND *csound, const csRtAudioParams * parm,
         free(dev->outused);
         free(dev);
         csound->rtRecord_userdata = NULL;
-        p->Message(csound, Str(" *** CoreAudio: open: memory allocation failure\n"));
+        p->Message(csound,
+                   Str(" *** CoreAudio: open: memory allocation failure\n"));
         return -1;
       }
       memset(dev->inbuffs[i], 0, buffbytes);
@@ -380,7 +382,8 @@ int coreaudio_open(CSOUND *csound, const csRtAudioParams * parm,
         free(dev->outused);
         free(dev);
         csound->rtRecord_userdata = NULL;
-        p->Message(csound, Str(" *** CoreAudio: open: memory allocation failure\n"));
+        p->Message(csound,
+                   Str(" *** CoreAudio: open: memory allocation failure\n"));
         return -1;
       }
       memset(dev->outbuffs[i], 0, buffbytes);
@@ -390,7 +393,12 @@ int coreaudio_open(CSOUND *csound, const csRtAudioParams * parm,
     dev->incurbuff = dev->outcurbuff = dev->iocurbuff = 0;
     dev->incount = dev->outcount = 0;
 
+    // 
+#if defined(MAC_OS_X_VERSION_10_5) && (MAC_OS_X_VERSION_MIN_REQUIRED>=MAC_OS_X_VERSION_10_5)
+    AudioDeviceCreateIOProcID(dev->dev,Csound_IOProcEntry,dev,&dev->procID);
+#else
     AudioDeviceAddIOProc(dev->dev, Csound_IOProcEntry, dev);
+#endif
     AudioDeviceStart(dev->dev, Csound_IOProcEntry);
 
     if (isInput)
@@ -538,8 +546,13 @@ static void rtclose_(CSOUND *csound)
     dev = (DEVPARAMS *) (csound->rtRecord_userdata);
     if (dev != NULL) {
       p->Message(csound, Str("coreaudio module: closing device...\n"));
+      sleep(1);
       AudioDeviceStop(dev->dev, Csound_IOProcEntry);
+#if defined(MAC_OS_X_VERSION_10_5) && (MAC_OS_X_VERSION_MIN_REQUIRED>=MAC_OS_X_VERSION_10_5)
+      AudioDeviceDestroyIOProcID(dev->dev, dev->procID);
+#else
       AudioDeviceRemoveIOProc(dev->dev, Csound_IOProcEntry);
+#endif
       csound->rtRecord_userdata = NULL;
       free(dev->outbuffs);
       free(dev->inbuffs);
