@@ -1065,13 +1065,13 @@ int inch_opcode(CSOUND *csound, INCH *p)
     MYFLT *sp = csound->spin + (ch - 1);
     MYFLT *ain = p->ar;
     CSOUND_SPIN_SPINLOCK
-    if (UNLIKELY(ch > csound->nchnls)) {
+    if (UNLIKELY(ch > csound->nchnls_i)) {
       CSOUND_SPIN_SPINUNLOCK
       return NOTOK;
     }
     for (n = 0; n < nsmps; n++) {
       ain[n] = *sp;
-      sp += csound->nchnls;
+      sp += csound->nchnls_i;
     }
     CSOUND_SPIN_SPINUNLOCK
     return OK;
@@ -1084,14 +1084,14 @@ int inall_opcode(CSOUND *csound, INALL *p)
     int   i, j = 0, k = 0, nsmps = csound->ksmps;
     MYFLT *spin = csound->spin;
     CSOUND_SPIN_SPINLOCK
-    m = (n < csound->nchnls ? n : csound->nchnls);
+    m = (n < csound->nchnls_i ? n : csound->nchnls_i);
     for (j=0; j<nsmps; j++) {
       for (i=0; i<m; i++) {
         p->ar[i][j] = spin[k + i];
       }
       for ( ; i < n; i++)
         p->ar[i][j] = FL(0.0);
-      k += csound->nchnls;
+      k += csound->nchnls_i;
     }
     CSOUND_SPIN_SPINUNLOCK
     return OK;
