@@ -89,7 +89,6 @@ static CS_NOINLINE int chan_realloc_f(CSOUND *csound,
     return CSOUND_SUCCESS;
 }
 
-
 /**
 * Sends a MYFLT value to the chani opcode (k-rate) at index 'n'.
 * The bus is automatically extended if 'n' exceeds any previously used
@@ -176,6 +175,64 @@ PUBLIC int csoundChanOAGet(CSOUND *csound, MYFLT *value, int n)
     return CSOUND_SUCCESS;
 }
 
+PUBLIC int csoundChanIKSetValue(CSOUND *csound, int n, MYFLT value)
+{
+    if (n < 0)
+      return CSOUND_ERROR;
+    if ((unsigned int)n >= (unsigned int)csound->nchanik) {
+      int   err = chan_realloc(csound,
+                               &(csound->chanik), &(csound->nchanik), n + 1);
+      if (UNLIKELY(err))
+        return err;
+    }
+    csound->chanik[n] = value;
+    return CSOUND_SUCCESS;
+}
+
+PUBLIC MYFLT csoundChanOKGetValue(CSOUND *csound, int n)
+{
+  if (n < 0)
+    return CSOUND_ERROR;
+  if ((unsigned int)n >= (unsigned int)csound->nchanok) {
+    int   err = chan_realloc(csound,
+			     &(csound->chanok), &(csound->nchanok), n + 1);
+    if (UNLIKELY(err))
+      return err;
+  }
+  return csound->chanok[n];
+}
+
+PUBLIC int csoundChanIASetSample(CSOUND *csound, int n, int i, MYFLT sample)
+{
+  if (n < 0)
+    return CSOUND_ERROR;
+  n *= csound->ksmps;
+  if ((unsigned int)n >= (unsigned int)csound->nchanoa) {
+    int   err = chan_realloc(csound, &(csound->chanoa),
+			     &(csound->nchanoa), n + csound->ksmps);
+    if (UNLIKELY(err))
+      return err;
+  }
+  csound->chanoa[n + i] = sample;
+  return CSOUND_SUCCESS;
+}
+
+
+PUBLIC MYFLT csoundChanOAGetSample(CSOUND *csound, int n, int i)
+{
+  if (n < 0)
+    return CSOUND_ERROR;
+  n *= csound->ksmps;
+  if ((unsigned int)n >= (unsigned int)csound->nchanoa) {
+    int   err = chan_realloc(csound, &(csound->chanoa),
+			     &(csound->nchanoa), n + csound->ksmps);
+    if (UNLIKELY(err))
+      return err;
+  }
+  return csound->chanoa[n + i];
+}
+
+
 /**
 * Sends a PVSDATEX fin to the pvsin opcode (f-rate) at index 'n'.
 * The bus is automatically extended if 'n' exceeds any previously used
@@ -202,7 +259,8 @@ PUBLIC int csoundPvsinSet(CSOUND *csound, const PVSDATEXT *fin, int n)
     }
     size = fout[n].N < fin->N ? fout[n].N : fin->N;
     memcpy(&fout[n], fin, sizeof(PVSDATEXT)-sizeof(float *));
-    memcpy(fout[n].frame, fin->frame, sizeof(float)*(size+2));
+    if (size > 0)
+       memcpy(fout[n].frame, fin->frame, sizeof(float)*(size+2));
     return CSOUND_SUCCESS;
 }
 
@@ -229,7 +287,8 @@ PUBLIC int csoundPvsoutGet(CSOUND *csound, PVSDATEXT *fout, int n)
     }
     size = fout->N < fin[n].N ? fout->N : fin[n].N;
     memcpy(fout, &fin[n], sizeof(PVSDATEXT)-sizeof(float *));
-    memcpy(fout->frame, fin[n].frame, sizeof(float)*(size+2));
+    if (size > 0)
+      memcpy(fout->frame, fin[n].frame, sizeof(float)*(size+2));
     return CSOUND_SUCCESS;
 }
 
@@ -332,13 +391,13 @@ int pvsin_perf(CSOUND *csound, FCHAN *p)
     PVSDAT *fout = p->r;
     int     n = (int)MYFLT2LRND(*(p->a)), size;
     if (UNLIKELY(n < 0))
-      return csound->PerfError(csound, Str("chani: invalid index"));
+      return csound->PerfError(csound, Str("pvsin: invalid index"));
     if (((unsigned int)n >= (unsigned int)csound->nchanif)){
       int err = chan_realloc_f(csound, (void *)&(csound->chanif),
                                &(csound->nchanif), n + 1,
                                (void *) &(p->init));
       if (UNLIKELY(err)) {
-        return csound->PerfError(csound, Str("chani: memory allocation failure"));
+        return csound->PerfError(csound, Str("pvsin: memory allocation failure"));
       }
       else {
         fin = (PVSDATEXT *)csound->chanif;
@@ -357,14 +416,14 @@ int pvsout_perf(CSOUND *csound, FCHAN *p)
     PVSDATEXT *fout = (PVSDATEXT *)csound->chanof;
     PVSDAT *fin = p->r;
     if (UNLIKELY(n < 0))
-      return csound->PerfError(csound,Str("chano: invalid index"));
+      return csound->PerfError(csound,Str("pvsout: invalid index"));
 
     if ((unsigned int)n >= (unsigned int)csound->nchanof) {
       if (UNLIKELY(chan_realloc_f(csound, (void *)&(csound->chanof),
                                   &(csound->nchanof), n + 1,
                                   (void *) fin) != 0))
         return csound->PerfError(csound,
-                                 Str("chano: memory allocation failure"));
+                                 Str("pvsout: memory allocation failure"));
       else fout = (PVSDATEXT *)csound->chanof;
     }
     size = fout[n].N < fin->N ? fout[n].N : fin->N;
@@ -387,6 +446,7 @@ typedef struct channelEntry_s {
     struct channelEntry_s *nxt;
     controlChannelInfo_t  *info;
     MYFLT   *data;
+    int     lock;               /* Multi-thread protection */
     int     type;
     char    name[1];
 } channelEntry_t;
@@ -398,8 +458,9 @@ static int delete_channel_db(CSOUND *csound, void *p)
 
     (void) p;
     db = (channelEntry_t**) csound->chn_db;
-    if (db == NULL)
+    if (db == NULL) {
       return 0;
+    }
     for (i = 0; i < 256; i++) {
       while (db[i] != NULL) {
         pp = db[i];
@@ -562,6 +623,17 @@ PUBLIC int csoundGetChannelPtr(CSOUND *csound,
     return create_new_channel(csound, p, name, type);
 }
 
+PUBLIC int *csoundGetChannelLock(CSOUND *csound,
+                                const char *name, int type)
+{
+    channelEntry_t  *pp;
+
+    if (UNLIKELY(name == NULL))
+      return NULL;
+    pp = find_channel(csound, name);
+    return &pp->lock;
+}
+
 static int cmp_func(const void *p1, const void *p2)
 {
     return strcmp(((CsoundChannelListEntry*) p1)->name,
@@ -870,7 +942,10 @@ static int chnset_opcode_perf_k(CSOUND *csound, CHNGET *p)
 
 static int chnset_opcode_perf_a(CSOUND *csound, CHNGET *p)
 {
+    int *lock = p->lock;        /* Need lock for the channel */
+    csoundSpinLock(lock);
     memcpy(p->fp, p->arg, sizeof(MYFLT)*csound->ksmps);
+    csoundSpinUnLock(lock);
     return OK;
 }
 
@@ -880,9 +955,12 @@ static int chnmix_opcode_perf(CSOUND *csound, CHNGET *p)
 {
     int   i = 0;
     int n = csound->ksmps;
+    int *lock = p->lock;        /* Need lock for the channel */
+    csoundSpinLock(lock);
     for (i=0; i<n; i++) {
       p->fp[i] += p->arg[i];
     }
+    csoundSpinUnLock(lock);
     return OK;
 }
 
@@ -890,7 +968,10 @@ static int chnmix_opcode_perf(CSOUND *csound, CHNGET *p)
 
 static int chnclear_opcode_perf(CSOUND *csound, CHNCLEAR *p)
 {
+    int *lock = p->lock;        /* Need lock for the channel */
+    csoundSpinLock(lock);
     memset(p->fp, 0, csound->ksmps*sizeof(MYFLT));
+    csoundSpinUnLock(lock);
     return OK;
 }
 
@@ -899,12 +980,17 @@ static int chnclear_opcode_perf(CSOUND *csound, CHNCLEAR *p)
 int chnset_opcode_init_i(CSOUND *csound, CHNGET *p)
 {
     int   err;
+    int *lock;        /* Need lock for the channel */
 
     err = csoundGetChannelPtr(csound, &(p->fp), (char*) p->iname,
                               CSOUND_CONTROL_CHANNEL | CSOUND_OUTPUT_CHANNEL);
     if (UNLIKELY(err))
       return print_chn_err(p, err);
+    p->lock = lock = csoundGetChannelLock(csound, (char*) p->iname,
+                                CSOUND_CONTROL_CHANNEL | CSOUND_OUTPUT_CHANNEL);
+    csoundSpinLock(lock);
     *(p->fp) = *(p->arg);
+    csoundSpinUnLock(lock);
 
     return OK;
 }
@@ -918,6 +1004,8 @@ int chnset_opcode_init_k(CSOUND *csound, CHNGET *p)
     err = csoundGetChannelPtr(csound, &(p->fp), (char*) p->iname,
                               CSOUND_CONTROL_CHANNEL | CSOUND_OUTPUT_CHANNEL);
     if (LIKELY(!err)) {
+      p->lock = csoundGetChannelLock(csound, (char*) p->iname,
+                                CSOUND_CONTROL_CHANNEL | CSOUND_OUTPUT_CHANNEL);
       p->h.opadr = (SUBR) chnset_opcode_perf_k;
       return OK;
     }
@@ -933,6 +1021,8 @@ int chnset_opcode_init_a(CSOUND *csound, CHNGET *p)
     err = csoundGetChannelPtr(csound, &(p->fp), (char*) p->iname,
                               CSOUND_AUDIO_CHANNEL | CSOUND_OUTPUT_CHANNEL);
     if (!err) {
+      p->lock = csoundGetChannelLock(csound, (char*) p->iname,
+                                CSOUND_AUDIO_CHANNEL | CSOUND_OUTPUT_CHANNEL);
       p->h.opadr = (SUBR) chnset_opcode_perf_a;
       return OK;
     }
@@ -948,6 +1038,8 @@ int chnmix_opcode_init(CSOUND *csound, CHNGET *p)
     err = csoundGetChannelPtr(csound, &(p->fp), (char*) p->iname,
                               CSOUND_AUDIO_CHANNEL | CSOUND_OUTPUT_CHANNEL);
     if (LIKELY(!err)) {
+      p->lock = csoundGetChannelLock(csound, (char*) p->iname,
+                                CSOUND_AUDIO_CHANNEL | CSOUND_OUTPUT_CHANNEL);
       p->h.opadr = (SUBR) chnmix_opcode_perf;
       return OK;
     }
@@ -975,7 +1067,7 @@ int chnclear_opcode_init(CSOUND *csound, CHNCLEAR *p)
 int chnset_opcode_init_S(CSOUND *csound, CHNGET *p)
 {
     int   err;
-
+    int  *lock;
     err = csoundGetChannelPtr(csound, &(p->fp), (char*) p->iname,
                               CSOUND_STRING_CHANNEL | CSOUND_OUTPUT_CHANNEL);
     if (UNLIKELY(err))
@@ -984,7 +1076,12 @@ int chnset_opcode_init_S(CSOUND *csound, CHNGET *p)
       /* can only happen with constants */
       return csound->InitError(csound, Str("string is too long"));
     }
+    p->lock = lock =
+      csoundGetChannelLock(csound, (char*) p->iname,
+                           CSOUND_STRING_CHANNEL | CSOUND_OUTPUT_CHANNEL);
+    csoundSpinLock(lock);
     strcpy((char*) p->fp, (char*) p->arg);
+    csoundSpinLock(lock);
 
     return OK;
 }
@@ -1010,8 +1107,10 @@ int chn_k_opcode_init(CSOUND *csound, CHN_OPCODE_K *p)
     type = (int)MYFLT2LRND(*(p->itype));
     err = csoundSetControlChannelParams(csound, (char*) p->iname, type,
                                         *(p->idflt), *(p->imin), *(p->imax));
-    if (LIKELY(!err))
+    if (LIKELY(!err)) {
+      p->lock = csoundGetChannelLock(csound, (char*) p->iname, type);
       return OK;
+    }
     if (err == CSOUND_MEMORY)
       return print_chn_err(p, err);
     return csound->InitError(csound, Str("invalid channel parameters"));
@@ -1056,6 +1155,7 @@ int chn_S_opcode_init(CSOUND *csound, CHN_OPCODE *p)
     err = csoundGetChannelPtr(csound, &dummy, (char*) p->iname, type);
     if (UNLIKELY(err))
       return print_chn_err(p, err);
+    p->lock = csoundGetChannelLock(csound, (char*) p->iname, type);
     return OK;
 }
 
@@ -1066,6 +1166,7 @@ int chnexport_opcode_init(CSOUND *csound, CHNEXPORT_OPCODE *p)
     MYFLT       *dummy;
     const char  *argName;
     int         type = CSOUND_CONTROL_CHANNEL, mode, err;
+    int         *lock;
 
     /* must have an output argument of type 'gi', 'gk', 'ga', or 'gS' */
     if (UNLIKELY(csound->GetOutputArgCnt(p) != 1))
@@ -1102,7 +1203,11 @@ int chnexport_opcode_init(CSOUND *csound, CHNEXPORT_OPCODE *p)
       return csound->InitError(csound, Str("channel already exists"));
     /* now create new channel, using output variable for data storage */
     dummy = p->arg;
+    /* THIS NEEDS A LOCK BUT DOES NOT EXIST YET */
+    /* lock = csoundGetChannelLock(csound, (char*) p->iname, 0); */
+    /* csoundSpinLock(lock); */
     err = create_new_channel(csound, &dummy, (char*) p->iname, type);
+    /* csoundSpinLock(lock); */
     if (err)
       return print_chn_err(p, err);
     /* if control channel, set additional parameters */
