@@ -152,9 +152,9 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
       FILE    *f;
       void    *fd;
       char    *filemode = (char*)fileParams;
-      
+
       /* akozar: csFileType cannot be as specific as I'd like since it is not
-         possible to know the real file type until this handle is used */ 
+         possible to know the real file type until this handle is used */
       if ((strcmp(filemode, "rb") == 0 || (strcmp(filemode, "wb") == 0)))
             csFileType = CSFTYPE_OTHER_BINARY;
       else  csFileType = CSFTYPE_OTHER_TEXT;
@@ -165,6 +165,7 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
         csound->Free(csound, name);
         return -1;
       }
+      /*      setvbuf(f, (char *) NULL, _IOLBF, 0); /* Ensure line buffering */
       pp->file_opened[idx].raw = f;
       pp->file_opened[idx].fd = fd;
     }
@@ -819,7 +820,7 @@ static int fprintf_set(CSOUND *csound, FPRINTF *p)
                          p->fname, p->XSTRCODE & 1, "w");
     if (UNLIKELY(n < 0))
       return NOTOK;
-
+    setvbuf(p->f.f, (char*)NULL, _IOLBF, 0); /* Seems a good option */
     /* Copy the string to the storage place in PRINTKS.
      *
      * We will look out for certain special codes and write special
@@ -1028,7 +1029,7 @@ static int fprintf_i(CSOUND *csound, FPRINTF *p)
       return NOTOK;
     sprints(string, p->txtstring, p->argums, p->INOCOUNT - 2);
     fprintf(p->f.f, string);
-
+    /* fflush(p->f.f); */
     return OK;
 }
 
