@@ -1189,8 +1189,9 @@ int specfilt(CSOUND *csound, SPECFILT *p)
       MYFLT curval, *coefp = p->coefs;
       MYFLT *persp = p->states;
       int   n,npts = inspecp->npts;
-      
-      if (UNLIKELY(newp==NULL || outp==NULL || coefp==NULL || persp==NULL))  /* RWD */
+
+      if (UNLIKELY(newp==NULL || outp==NULL ||
+                   coefp==NULL || persp==NULL))  /* RWD */
         goto err1;
       for (n=0; n<npts;n++) {                      /* for npts of inspec:     */
         outp[n] = curval = persp[n];               /*   output current point  */
@@ -1239,6 +1240,7 @@ static OENTRY localops[] = {
 { "pinkish", S(PINKISH),  5, "a", "xoooo", (SUBR)pinkset, NULL, (SUBR)pinkish },
 { "noise",  S(VARI),   5,    "a", "xk",   (SUBR)varicolset, NULL, (SUBR)varicol },
 { "transeg", S(TRANSEG), 7,  "s", "iiim", (SUBR)trnset,(SUBR)ktrnseg,(SUBR)trnseg},
+{ "transegr", S(TRANSEG), 7, "s", "iiim", (SUBR)trnsetr,(SUBR)ktrnsegr,(SUBR)trnsegr},
 { "clip", S(CLIP),       5,  "a", "aiiv", (SUBR)clip_set, NULL, (SUBR)clip  },
 { "cpuprc", S(CPU_PERC), 1,     "",     "ii",   (SUBR)cpuperc, NULL, NULL   },
 { "maxalloc", S(CPU_PERC), 1,   "",     "ii",   (SUBR)maxalloc, NULL, NULL  },
@@ -1247,7 +1249,7 @@ static OENTRY localops[] = {
 { "active.k", S(INSTCNT),2,     "k",    "k",    NULL, (SUBR)instcount, NULL },
 { "p.i", S(PFUN),        1,     "i",    "i",     (SUBR)pfun, NULL, NULL     },
 { "p.k", S(PFUN),        2,     "k",    "k",     NULL, (SUBR)pfun, NULL     },
-{ "mute", S(MUTE), 1,          "",      "So",   (SUBR)mute_inst             },
+{ "mute", S(MUTE), 1,          "",      "To",   (SUBR)mute_inst             },
 #ifdef BETA
 { "oscilv",  0xfffe                                                         },
 { "oscilv.kk", S(XOSC),  5,     "a",   "kkio", (SUBR)Foscset, NULL, (SUBR)Fosckk },
