@@ -48,11 +48,7 @@
  * See the STK class documentation to determine the controller numbers
  * used by each instrument.
  */
-#include <string>
-#include <map>
-#include <vector>
-#include <cstdlib>
-
+#include <Stk.h>
 #include <BandedWG.h>
 #include <BeeThree.h>
 #include <BlowBotl.h>
@@ -82,6 +78,16 @@
 #include <Whistle.h>
 #include <Wurley.h>
 
+using namespace stk;
+
+#include <cstdlib>
+#include <cstdio>
+#include <string>
+#include <map>
+#include <vector>
+
+using namespace std;
+
 #include <OpcodeBase.hpp>
 
 #include "csGblMtx.h"
@@ -589,6 +595,8 @@ extern "C"
         csound_global_mutex_lock();
         Stk::setRawwavePath(path);
         csound_global_mutex_unlock();
+        csound->Message(csound,
+			Str("RAWWAVE_PATH: %s\n"), Stk::rawwavePath().c_str());
       }
     int status = 0;
     for(OENTRY *oentry = &oentries[0]; oentry->opname; oentry++)
