@@ -1049,11 +1049,9 @@ static void band_energy_to_res(CSOUND *csound, ATSSINNOI *p)
     double  **partialband;
     int     *bandnum;
 
-    partialband = (double **) csound->Malloc(csound,
-                                             sizeof(double*)
-                                             * (int) p->atshead->npartials);
-    bandnum = (int *) csound->Malloc(csound, sizeof(int)
-                                             * (int) p->atshead->npartials);
+    partialband = (double **) malloc(sizeof(double*)
+                                     * (int) p->atshead->npartials);
+    bandnum = (int *) malloc(sizeof(int) * (int) p->atshead->npartials);
 
     for (i = 0; i < (int) p->atshead->nfrms; i++) {
       /* init sums */
@@ -1085,8 +1083,8 @@ static void band_energy_to_res(CSOUND *csound, ATSSINNOI *p)
       curframe += p->frmInc;
     }
 
-    csound->Free(csound, partialband);
-    csound->Free(csound, bandnum);
+    free(partialband);
+    free(bandnum);
 }
 
 static void fetchSINNOIpartials(ATSSINNOI *, MYFLT);
