@@ -151,39 +151,39 @@ static const char *longUsageList[] = {
   Str_noop("--nopeaks\t\tDo not write peak information"),
 #endif
   " ",
-  Str_noop("--nodisplays\t\tsuppress all displays"),
-  Str_noop("--asciidisplay\t\tsuppress graphics, use ascii displays"),
+  Str_noop("--nodisplays\t\tsUppress all displays"),
+  Str_noop("--asciidisplay\t\tSuppress graphics, use ascii displays"),
 #ifndef OLPC
-  Str_noop("--postscriptdisplay\tsuppress graphics, use Postscript displays"),
+  Str_noop("--postscriptdisplay\tSuppress graphics, use Postscript displays"),
 #endif
   " ",
-  Str_noop("--defer-gen1\t\tdefer GEN01 soundfile loads until performance time"),
-  Str_noop("--iobufsamps=N\t\tsample frames (or -kprds) per software sound I/O buffer"),
-  Str_noop("--hardwarebufsamps=N\tsamples per hardware sound I/O buffer"),
-  Str_noop("--cscore\t\tuse Cscore processing of scorefile"),
+  Str_noop("--defer-gen1\t\tDefer GEN01 soundfile loads until performance time"),
+  Str_noop("--iobufsamps=N\t\tSample frames (or -kprds) per software sound I/O buffer"),
+  Str_noop("--hardwarebufsamps=N\tSamples per hardware sound I/O buffer"),
+  Str_noop("--cscore\t\tUse Cscore processing of scorefile"),
   " ",
-  Str_noop("--midifile=FNAME\tread MIDIfile event stream from file"),
-  Str_noop("--midioutfile=FNAME\twrite MIDI output to file FNAME"),
-  Str_noop("--midi-device=FNAME\tread MIDI realtime events from device"),
-  Str_noop("--terminate-on-midi\tterminate the performance when miditrack is done"),
+  Str_noop("--midifile=FNAME\tRead MIDIfile event stream from file"),
+  Str_noop("--midioutfile=FNAME\tWrite MIDI output to file FNAME"),
+  Str_noop("--midi-device=FNAME\tRead MIDI realtime events from device"),
+  Str_noop("--terminate-on-midi\tTerminate the performance when miditrack is done"),
   " ",
 #ifndef OLPC
-  Str_noop("--heartbeat=N\t\tprint a heartbeat style 1, 2 or 3 at each soundfile write"),
-  Str_noop("--notify\t\tnotify (ring the bell) when score or miditrack is done"),
-  Str_noop("--rewrite\t\tcontinually rewrite header while writing soundfile (WAV/AIFF)"),
+  Str_noop("--heartbeat=N\t\tPrint a heartbeat style 1, 2 or 3 at each soundfile write"),
+  Str_noop("--notify\t\tNotify (ring the bell) when score or miditrack is done"),
+  Str_noop("--rewrite\t\tContinually rewrite header while writing soundfile (WAV/AIFF)"),
   " ",
 #endif
-  Str_noop("--input=FNAME\t\tsound input filename"),
-  Str_noop("--output=FNAME\t\tsound output filename"),
-  Str_noop("--logfile=FNAME\t\tlog output to file"),
+  Str_noop("--input=FNAME\t\tSound input filename"),
+  Str_noop("--output=FNAME\t\tSound output filename"),
+  Str_noop("--logfile=FNAME\t\tLog output to file"),
   " ",
-  Str_noop("--nosound\t\tno sound onto disk or device"),
-  Str_noop("--tempo=N\t\tuse uninterpreted beats of the score, initially at tempo N"),
+  Str_noop("--nosound\t\tNo sound onto disk or device"),
+  Str_noop("--tempo=N\t\tUse uninterpreted beats of the score, initially at tempo N"),
   Str_noop("--i-only\t\tI-time only orch run"),
-  Str_noop("--syntax-check-only\tstop after checking orchestra and score syntax"),
-  Str_noop("--control-rate=N\torchestra krate override"),
-  Str_noop("--sample-rate=N\t\torchestra srate override"),
-  Str_noop("--score-in=FNAME\tread Line-oriented realtime score events from device"),
+  Str_noop("--syntax-check-only\tStop after checking orchestra and score syntax"),
+  Str_noop("--control-rate=N\tOrchestra krate override"),
+  Str_noop("--sample-rate=N\t\tOrchestra srate override"),
+  Str_noop("--score-in=FNAME\tRead Line-oriented realtime score events from device"),
   Str_noop("--messagelevel=N\ttty message level, sum of:"),
   Str_noop("--messageolevel=O\ttty message level in octal, of:"),
   Str_noop("\t\t\t\t1=note amps, 2=out-of-range msg, 4=warnings,"),
@@ -191,29 +191,29 @@ static const char *longUsageList[] = {
   Str_noop("\t\t\t\t128=print benchmark information"),
   " ",
   Str_noop("--m-amps=[01]\tmessages on note amps"),
-  Str_noop("--m-range=[01]\tmessages on range errors"),
-  Str_noop("--m-warnings=[01]\tmesage on warnings"),
-  Str_noop("--m-raw=[01]\traw amp messages"),
-  Str_noop("--m-dB=[01]\tamp messages in dB"),
-  Str_noop("--m-colours=[01]\tcolour amp messages"),
-  Str_noop("--m-benchmarks=[01]\tprint benchmark information"),
-  Str_noop("--csd-line-nums=[01]\tcontrols how error line numbers are printed:"),
+  Str_noop("--m-range=[01]\tMessages on range errors"),
+  Str_noop("--m-warnings=[01]\tMesage on warnings"),
+  Str_noop("--m-raw=[01]\tRaw amp messages"),
+  Str_noop("--m-dB=[01]\tAmp messages in dB"),
+  Str_noop("--m-colours=[01]\tColour amp messages"),
+  Str_noop("--m-benchmarks=[01]\tPrint benchmark information"),
+  Str_noop("--csd-line-nums=[01]\tControls how error line numbers are printed:"),
   Str_noop("\t\t\t1=use CSD line #s (default), 0=use ORC/SCO-relative line #s"),
-  Str_noop("--extract-score=FNAME\textract from score.srt using extract file"),
+  Str_noop("--extract-score=FNAME\tExtract from score.srt using extract file"),
   Str_noop("--keep-sorted-score"),
-  Str_noop("--expression-opt\toptimise use of temporary variables in expressions"),
-  Str_noop("--env:NAME=VALUE\tset environment variable NAME to VALUE"),
-  Str_noop("--env:NAME+=VALUE\tappend VALUE to environment variable NAME"),
-  Str_noop("--strsetN=VALUE\t\tset strset table at index N to VALUE"),
-  Str_noop("--utility=NAME\t\trun utility program"),
-  Str_noop("--verbose\t\tverbose orch translation"),
+  Str_noop("--expression-opt\tOptimise use of temporary variables in expressions"),
+  Str_noop("--env:NAME=VALUE\tSet environment variable NAME to VALUE"),
+  Str_noop("--env:NAME+=VALUE\tAppend VALUE to environment variable NAME"),
+  Str_noop("--strsetN=VALUE\t\tSet strset table at index N to VALUE"),
+  Str_noop("--utility=NAME\t\tRun utility program"),
+  Str_noop("--verbose\t\tVerbose orch translation"),
   Str_noop("--list-opcodes\t\tList opcodes in this version"),
   Str_noop("--list-opcodesN\t\tList opcodes in style N in this version"),
   Str_noop("--dither\t\tDither output"),
   Str_noop("--dither-triangular\t\tDither output with triangular distribution"),
   Str_noop("--dither-uniform\t\tDither output with rectanular distribution"),
-  Str_noop("--sched\t\t\tset real-time scheduling priority and lock memory"),
-  Str_noop("--sched=N\t\tset priority to N and lock memory"),
+  Str_noop("--sched\t\t\tSet real-time scheduling priority and lock memory"),
+  Str_noop("--sched=N\t\tSet priority to N and lock memory"),
   Str_noop("--opcode-lib=NAMES\tDynamic libraries to load"),
   Str_noop("--omacro:XXX=YYY\tSet orchestra macro XXX to value YYY"),
   Str_noop("--smacro:XXX=YYY\tSet score macro XXX to value YYY"),
@@ -229,7 +229,11 @@ static const char *longUsageList[] = {
   Str_noop("\t\t\tvelocity number to pfield N as MIDI value [0-127]"),
   Str_noop("--midi-velocity-amp=N\tRoute MIDI note on message"),
   Str_noop("\t\t\tvelocity number to pfield N as amplitude"),
-  Str_noop("--no-default-paths\tturn off relative paths from CSD/ORC/SCO"),
+  Str_noop("--no-default-paths\tTurn off relative paths from CSD/ORC/SCO"),
+#if ENABLE_NEW_PARSER
+  Str_noop("--new-parser\t\tUse new Bison-based parser"),
+  Str_noop("--old-parser\t\tUse old parser"),
+#endif
   " ",
   Str_noop("--help\t\t\tLong help"),
   NULL
@@ -887,6 +891,10 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->newParser = 1;             /* Use New Parser */
       return 1;
     }
+    else if (!(strcmp(s, "old-parser"))) {
+      O->newParser = 0;             /* Use Old Parser */
+      return 1;
+    }
 #endif
 
     csoundErrorMsg(csound, Str("unknown long option: '--%s'"), s);
