@@ -124,15 +124,40 @@ namespace csound
     return (a << 24) + (b << 16) + (c << 8) + d;
   }
 
+  Chunk::Chunk() :
+    id(0),
+    chunkSize(0),
+    chunkSizePosition(0),
+    chunkStart(0),
+    chunkEnd(0)
+  {
+  }
+
   Chunk::Chunk(const char *_id)
   {
     id = MidiFile::chunkName(_id[0], _id[1], _id[2], _id[3]);
   }
 
+  Chunk::Chunk(const Chunk &a)
+  {
+    *this = a;
+  }
+
   Chunk::~Chunk()
   {
   }
 
+  Chunk &Chunk::operator = (const Chunk &a)
+  {
+    if (this != &a) {
+      id = a.id;
+      chunkSize = a.chunkSize;
+      chunkSizePosition = a.chunkSizePosition;
+      chunkStart = a.chunkStart;
+      chunkEnd = a.chunkEnd;
+    }
+  }
+
   void Chunk::read(std::istream &stream)
   {
     int _id = MidiFile::readInt(stream);
@@ -185,11 +210,30 @@ namespace csound
     clear();
   }
 
+  MidiHeader::MidiHeader(const MidiHeader &a)
+  {
+    *this = a;
+  }
+
   MidiHeader::~MidiHeader()
   {
     clear();
   }
 
+  MidiHeader &MidiHeader::operator = (const MidiHeader &a)
+  {
+    if (this != &a) {
+      id = a.id;
+      chunkSize = a.chunkSize;
+      chunkSizePosition = a.chunkSizePosition;
+      chunkStart = a.chunkStart;
+      chunkEnd = a.chunkEnd;
+      type = a.type;
+      trackCount = a.trackCount;
+      timeFormat = a.timeFormat;
+    }
+  }
+
   void MidiHeader::clear()
   {
     type = 0;
@@ -218,63 +262,74 @@ namespace csound
   {
   }
 
+  MidiEvent::MidiEvent(const MidiEvent &a)
+  {
+    *this = a;
+  }
+
   MidiEvent::~MidiEvent()
   {
   }
 
-  void MidiEvent::write(std::ostream &stream, MidiFile &midiFile, int lastTick)
+  MidiEvent &MidiEvent::operator = (const MidiEvent &a)
+  {
+    if (this != &a) {
+      this->ticks = a.ticks;
+      this->time = a.time;
+      resize(a.size());
+      for (size_t i = 0; i < a.size(); i++) {
+        (*this)[i] = a[i];
+      }
+    }
+    return *this;
+  }
+
+  void MidiEvent::write(std::ostream &stream, const MidiFile &midiFile, int lastTick) const
   {
     int deltaTicks = ticks - lastTick;
     MidiFile::writeVariableLength(stream, deltaTicks);
     //  Channel event.
-    if(getMetaType() < 0)
-      {
-        for(size_t i = 0, n = size(); i < n; i++)
-          {
-            stream.put((*this)[i]);
-          }
+    if(getStatusNybble() != 0xf) {
+      for(size_t i = 0, n = size(); i < n; i++) {
+        stream.put((*this)[i]);
       }
-    //  Meta event.
-    else
-      {
-        stream.put((*this)[0]);
-        stream.put((*this)[1]);
-        size_t n = getMetaSize();
-        MidiFile::writeVariableLength(stream, (int) n);
-        size_t i;
-        for(i = 3, n = size(); i < n; i++)
-          {
-            stream.put((*this)[i]);
-          }
+      // Meta event.
+    } else {
+      stream.put(getStatus());
+      stream.put(getMetaType());
+      MidiFile::writeVariableLength(stream, getMetaSize());
+      for(size_t i = 0, n = getMetaSize(); i < n; i++) {
+        stream.put((*this)[2 + i]);
       }
+    }
   }
 
-  int MidiEvent::getStatus()
+  int MidiEvent::getStatus() const
   {
     return (*this)[0];
   }
 
-  int MidiEvent::getStatusNybble()
+  int MidiEvent::getStatusNybble() const
   {
     return (*this)[0] & 0xf0;
   }
 
-  int MidiEvent::getChannelNybble()
+  int MidiEvent::getChannelNybble() const
   {
     return (*this)[0] & 0x0f;
   }
 
-  int MidiEvent::getKey()
+  int MidiEvent::getKey() const
   {
     return (*this)[1];
   }
 
-  int MidiEvent::getVelocity()
+  int MidiEvent::getVelocity() const
   {
     return (*this)[2];
   }
 
-  int MidiEvent::getMetaType()
+  int MidiEvent::getMetaType() const
   {
     if(getStatus() == MidiFile::META_EVENT)
       {
@@ -283,12 +338,12 @@ namespace csound
     return -1;
   }
 
-  unsigned char MidiEvent::getMetaData(int i)
+  unsigned char MidiEvent::getMetaData(int i) const
   {
     return (*this)[i + 2];
   }
 
-  size_t MidiEvent::getMetaSize()
+  size_t MidiEvent::getMetaSize() const
   {
     return (size() - 2);
   }
@@ -304,7 +359,7 @@ namespace csound
     return (unsigned char) c;
   }
 
-  bool MidiEvent::isChannelVoiceMessage()
+  bool MidiEvent::isChannelVoiceMessage() const
   {
     if(getStatusNybble() < MidiFile::CHANNEL_NOTE_OFF)
       {
@@ -317,7 +372,7 @@ namespace csound
     return true;
   }
 
-  bool MidiEvent::isNoteOn()
+  bool MidiEvent::isNoteOn() const
   {
     if(getStatusNybble() == MidiFile::CHANNEL_NOTE_ON && (*this)[2] > 0)
       {
@@ -326,7 +381,7 @@ namespace csound
     return false;
   }
 
-  bool MidiEvent::isNoteOff()
+  bool MidiEvent::isNoteOff() const
   {
     if(getStatusNybble() == MidiFile::CHANNEL_NOTE_OFF)
       {
@@ -339,7 +394,7 @@ namespace csound
     return false;
   }
 
-  bool MidiEvent::isMatchingNoteOff(MidiEvent &offEvent)
+  bool MidiEvent::matchesNoteOffEvent(const MidiEvent &offEvent) const
   {
     if(getChannelNybble() != offEvent.getChannelNybble())
       {
@@ -353,7 +408,7 @@ namespace csound
       {
         return false;
       }
-    if(!(offEvent.time > time))
+    if(!(offEvent.ticks >= ticks))
       {
         return false;
       }
@@ -372,6 +427,21 @@ namespace csound
   {
   }
 
+  MidiTrack &MidiTrack::operator = (const MidiTrack &a)
+  {
+    if (this != &a) {
+      id = a.id;
+      chunkSize = a.chunkSize;
+      chunkSizePosition = a.chunkSizePosition;
+      chunkStart = a.chunkStart;
+      chunkEnd = a.chunkEnd;
+      resize(a.size());
+      for (size_t i = 0; i < size(); i++) {
+        (*this)[i] = a[i];
+      }
+    }
+  }
+
   void MidiTrack::read(std::istream &stream, MidiFile &midiFile)
   {
     Chunk::read(stream);
@@ -400,7 +470,7 @@ namespace csound
       {
         secondsPerTick = midiFile.currentSecondsPerTick;
       }
-    time = midiFile.currentTime = (midiFile.currentTime + (secondsPerTick * ticks));
+    this->time = midiFile.currentTime = (midiFile.currentTime + (secondsPerTick * ticks));
     int peeked = stream.peek();
     if(stream.eof())
       {
@@ -546,7 +616,7 @@ namespace csound
     currentSecondsPerTick = 0;
     lastStatus = 0;
     midiHeader.clear();
-    midiTracks.erase(midiTracks.begin(), midiTracks.end());
+    midiTracks.clear();
     tempoMap.erase(tempoMap.begin(), tempoMap.end());
     microsecondsPerQuarterNote = (60.0 / 120.0) * 1000000.0;
     computeTimes();
@@ -594,6 +664,7 @@ namespace csound
       {
         int frameCode = (-midiHeader.timeFormat) >> 8;
         double framesPerSecond;
+        //cout << " frameCode:   " << frameCode;
         switch(frameCode)
           {
           case 24:
@@ -611,7 +682,9 @@ namespace csound
           default:
             framesPerSecond = 30.0;
           }
+        //cout << " framesPerSecond: " << framesPerSecond;
         int ticksPerFrame = midiHeader.timeFormat & 0xff;
+        //cout << " ticksPerFrame:   " << ticksPerFrame;
         currentSecondsPerTick = (1.0 / framesPerSecond) / ticksPerFrame;
       }
     else
@@ -619,7 +692,11 @@ namespace csound
         double ticksPerQuarterNote = double(midiHeader.timeFormat);
         double secondsPerQuarterNote = microsecondsPerQuarterNote / 1000000.0;
         currentSecondsPerTick = secondsPerQuarterNote / ticksPerQuarterNote;
+        //cout << " ticksPerQuarterNote:   " << ticksPerQuarterNote;
+        //cout << " secondsPerQuarterNote: " << secondsPerQuarterNote;
       }
+    //cout << " currentSecondsPerTick: " << currentSecondsPerTick;
+    //cout << endl;
     tempoMap[currentTick] = currentSecondsPerTick;
   }
 
@@ -646,22 +723,23 @@ namespace csound
       }
   }
 
-  void MidiFile::sort()
+  bool operator < (const MidiEvent &a, const MidiEvent &b)
   {
-    for(std::vector<MidiTrack>::iterator it = midiTracks.begin(); it != midiTracks.end(); ++it)
-      {
-        (*it).sort();
+    if (a.ticks < b.ticks) {
+      return true;
+    }
+    if (a.size() <= 0 && b.size() <= 0) {
+      return false;
+    }
+    size_t n = std::min(a.size(), b.size());
+    for (size_t i = 0; i < n; i++) {
+      if (a[i] < b[i]) {
+        return true;
       }
-  }
-
-  void MidiTrack::sort()
-  {
-    std::sort(begin(), end());
-  }
-
-  bool operator < (const MidiEvent &a, MidiEvent &b)
-  {
-
-    return (a.time < b.time);
+    }
+    if (a.size() < b.size()) {
+      return true;
+    }
+    return false;
   }
 }
