@@ -23,6 +23,7 @@
 #include "System.hpp"
 #include "Conversions.hpp"
 #include "Voicelead.hpp"
+
 #include <algorithm>
 #include <cfloat>
 #include <set>
@@ -31,10 +32,22 @@
 #include <fstream>
 #include <sstream>
 
+#if defined(HAVE_MUSICXML2)
+#include "elements.h"
+#include "factory.h"
+#include "xml.h"
+#include "xmlfile.h"
+#include "xml_tree_browser.h"
+#include "xmlreader.h"
+#include "midicontextvisitor.h"
+
+using namespace MusicXML2;
+#endif
+
 namespace csound
 {
 
-  void printChord(std::ostream &stream, std::string label, const std::vector<double> &chord) 
+  void printChord(std::ostream &stream, std::string label, const std::vector<double> &chord)
   {
     if (!( (System::getMessageLevel() & System::INFORMATION_LEVEL) == System::INFORMATION_LEVEL) ) {
       return;
@@ -49,7 +62,7 @@ namespace csound
     stream << "]" << std::endl;
   }
 
-  void printChord(std::string label, const std::vector<double> &chord) 
+  void printChord(std::string label, const std::vector<double> &chord)
   {
     if (!( (System::getMessageLevel() & System::INFORMATION_LEVEL) == System::INFORMATION_LEVEL) ) {
       return;
@@ -70,14 +83,97 @@ namespace csound
   {
   }
 
+#if defined(HAVE_MUSICXML2)
+
+  class ScoreMidiWriter : public midiwriter
+  {
+  public:
+    long tpq;
+    double tempo;
+    ScoreMidiWriter(Score *score_) : score(*score_), tpq(1000), tempo(1.0)
+    {
+      score.clear();
+      score.removeArrangement();
+    }
+    virtual void startPart (int instrCount)
+    {
+    }
+    virtual void newInstrument (std::string instrName, int chan=-1)
+    {
+    }
+    virtual void endPart (long date)
+    {
+    }
+    virtual void newNote (long start_, int channel_, float key_, int velocity_, int duration_)
+    {
+      double start = double(start_) / double(tpq) * tempo;
+      double duration = double(duration_) / double(tpq) * tempo;
+      double status = 144.0;
+      double channel = double(channel_);
+      double key = key_;
+      double velocity = velocity_;
+      score.append(start, duration, status, channel, key, velocity);
+    }
+    virtual void tempoChange (long date, int bpm)
+    {
+      tempo = 60.0 / double(bpm);
+    }
+    virtual void pedalChange (long date, pedalType t, int value)
+    {
+    }
+    virtual void volChange (long date, int chan, int vol)
+    {
+    }
+    virtual void bankChange (long date, int chan, int bank)
+    {
+    }
+    virtual void progChange (long date, int chan, int prog)
+    {
+    }
+  protected:
+    Score &score;
+  };
+
+#endif
+
   void Score::load(std::string filename)
   {
     System::inform("BEGAN Score::load(%s)...\n", filename.c_str());
-    std::ifstream stream;
-    //stream.open(filename.c_str(), std::ios_base::binary);
-    stream.open(filename.c_str(), std::ifstream::binary);
-    load(stream);
-    stream.close();
+    if (filename.find(".mid") != std::string::npos ||
+        filename.find(".MID") != std::string::npos) {
+      std::ifstream stream;
+      stream.open(filename.c_str(), std::ifstream::binary);
+      load(stream);
+      stream.close();
+    }
+#if defined(HAVE_MUSICXML2)
+    else if (filename.find(".xml") != std::string::npos ||
+             filename.find(".XML") != std::string::npos) {
+      xmlreader xmlReader;
+      Sxmlelement sxmlElement;
+      // Try to read an SXMLFile out of the MusicXML file.
+      SXMLFile sxmlFile = xmlReader.read(filename.c_str());
+      if (sxmlFile) {
+        // Get the document tree of XML elements from the SXMLFile.
+        sxmlElement = sxmlFile->elements();
+      }
+      if (sxmlElement) {
+        // Create a ScoreMidiWriter that is attached to this Score.
+        ScoreMidiWriter scoreMidiWriter(this);
+        // Create a midicontextvisitor, which calls into an abstract midiwriter interface,
+        // which is attached to our ScoreMidiWriter, which implements that midiwriter interface.
+        midicontextvisitor midicontextvisitor_(scoreMidiWriter.tpq, &scoreMidiWriter);
+        // Create an xml_tree_browser that is attached to our midicontextvisitor.
+        xml_tree_browser xmlTreeBrowser(&midicontextvisitor_);
+        // The xml_tree_browser will carry the midicontextvisitor to all the elements
+        // of the document tree, in the proper order, calling newNote as appropriate.
+        xmlTreeBrowser.browse(*sxmlElement);
+      }
+    }
+#endif
+    else {
+      System::error("Unknown file format in Score::load().");
+    }
     System::inform("ENDED Score::load().\n");
   }
 
@@ -88,15 +184,159 @@ namespace csound
     load(midiFile);
   }
 
+#if defined(HAVE_MUSICXML2_)
+  static Sxmlattribute newAttribute(const string& name, const string& value)
+  {
+    Sxmlattribute attribute = xmlattribute::create();
+    attribute->setName(name);
+    attribute->setValue(value);
+    return attribute;
+  }
+
+  static Sxmlattribute newAttributeI(const string& name, int value)
+  {
+    Sxmlattribute attribute = xmlattribute::create();
+    attribute->setName(name);
+    attribute->setValue(value);
+    return attribute;
+  }
+
+  static Sxmlelement newElement(int type, const string& value)
+  {
+    Sxmlelement elt = factory::instance().create(type);
+    elt->setValue (value);
+    return elt;
+  }
+
+  static Sxmlelement newElementI(int type, int value)
+  {
+    Sxmlelement elt = factory::instance().create(type);
+    elt->setValue (value);
+    return elt;
+  }
+
+  static Sxmlelement makeAttributes()
+  {
+    Sxmlelement attributes = factory::instance().create(k_attributes);
+    attributes->push (newElementI(k_divisions, 1000));
+    Sxmlelement time_ = factory::instance().create(k_time);
+    time_->push (newElement(k_beats, "4"));
+    time_->push (newElement(k_beat_type, "4"));
+    attributes->push (time_);
+    Sxmlelement clef = factory::instance().create(k_clef);
+    clef->push (newElement(k_sign, "G"));
+    clef->push (newElement(k_line, "2"));
+    attributes->push (clef);
+    return attributes;
+  }
+
+  static std::string makePartId(int partid)
+  {
+
+  }
+
+  static Sxmlelement makePart(int instrument, const std::vector<const Event *> &part_)
+  {
+    Sxmlelement part = factory::instance().create(k_part);
+    char buffer[0x100];
+    std::sprintf("Instrument %d", instrument);
+    part->add(newAttribute("id", buffer));
+    size_t measure = 0;
+    size_t time_ = 0;
+    size_t divisionsPerMeasure = 4 * 32;
+    // We have to quantize time in divisions of a quarter note.
+    // We assume that 32nd notes are good enough.
+    // We have to keep track of what measure we are in, and create new measures as required.
+    // We have to translate pitches to diatonic names, and get the accidental.
+    // And we have to back up to make chords.
+    return part;
+  }
+
+  static Sxmlelement makePartList(std::map<int, std::vector<const Event *> > parts)
+  {
+    Sxmlelement partlist = factory::instance().create(k_part_list);
+    for (std::map<int, std::vector<const Event *> >::iterator it = parts.begin(); it != parts.end(); ++it) {
+      Sxmlelement scorepart = factory::instance().create(k_score_part);
+      char partid[0x100];
+      std::sprintf(partid, "Instrument %d", it->first);
+      scorepart->add(newAttribute("id", partid));
+      scorepart->push(newElement(k_part_name, partid));
+      Sxmlelement scoreinstrument = factory::instance().create(k_score_instrument);
+      scoreinstrument->add(newAttribute("id", partid));
+      scoreinstrument->push(newElement(k_instrument_name, partid));
+      scorepart->push(scoreinstrument);
+      partlist->push(scorepart);
+    }
+    return partlist;
+  }
+
+  static Sxmlelement makeIdentification(Score &score)
+  {
+    Sxmlelement id = factory::instance().create(k_identification);
+    Sxmlelement encoding = factory::instance().create(k_encoding);
+    encoding->push (newElement(k_software, "MusicXML Library v2"));
+    id->push (encoding);
+    return id;
+  }
+
+  static Sxmlelement createScore(const Score &score_, std::string filename)
+  {
+    Sxmlelement score = factory::instance().create(k_score_partwise);
+    score->push (newElement(k_movement_title, filename().c_str()));
+    score->push (makeIdentification());
+    // Break up this Score into parts, each for one whole instrument number.
+    std::map<int, std::vector<const Event *> > parts;
+    for (size_t i = 0, n = size(); i < n; ++i) {
+      const Event &event = score_[i];
+      instrument = event.getInstrumentNumber();
+      parts[instrument].push_back(&event);
+    }
+    // First we have to make our part list.
+    score->push(makePartList(parts));
+    // Now add each Score part to the corresponding MusicXML part.
+    for (std::map<int, std::vector<Event *> >::iterator it = parts.begin(); it != parts.end(); ++it) {
+      const std::vector<const Event *> part = it->second;
+      score->push(makePart(part));
+     }
+    return score;
+  }
+#endif
+
   void Score::save(std::string filename)
   {
     System::inform("BEGAN Score::save(%s)...\n", filename.c_str());
     std::ofstream stream;
     //stream.open(filename.c_str(), std::ios_base::binary);
     stream.open(filename.c_str(), std::ifstream::binary);
-    save(stream);
+    if (filename.find(".mid") != std::string::npos ||
+        filename.find(".MID") != std::string::npos) {
+      save(stream);
+      System::inform("ENDED Score::save().\n");
+    }
+#if defined(HAVE_MUSICXML2_)
+    else if (filename.find(".xml") != std::string::npos ||
+             filename.find(".XML") != std::string::npos) {
+      // This Score has to be sorted first.
+      sort();
+      // Create an XMLFile to write to.
+      SXMLFile xmlFile = TXMLFile::create();
+      // Add an XML declaration to the XMLFile.
+      TXMLDecl xmlDeclaration = new TXMLDecl("1.0", "", TXMLDecl::kNo);
+      xmlFile->set(xmlDeclaration);
+      // Add a document type declaration.
+      TDocType documentTypeDeclaration = new TDocType("score-partwise");
+      xmlFile->set(documentTypeDeclaration);
+      // Create a MusicXML2 document in which first one part is written,
+      // then the next part, and so on.
+      xmlFile->set(createScore(*this, filename));
+      // Print the XML document to the output stream.
+      xmlFile->print(stream);
+    }
+#endif
+    else {
+      System::error("Unknown file format in Score::load().");
+    }
     stream.close();
-    System::inform("ENDED Score::save().\n");
   }
 
   void Score::save(std::ostream &stream)
@@ -173,12 +413,12 @@ namespace csound
     range = maximum - minimum;
   }
 
-  void Score::setScale(std::vector<Event> &score, 
-                       int dimension, bool rescaleMinimum, 
-                       bool rescaleRange, 
-                       size_t beginAt, 
-                       size_t endAt, 
-                       double targetMinimum, 
+  void Score::setScale(std::vector<Event> &score,
+                       int dimension, bool rescaleMinimum,
+                       bool rescaleRange,
+                       size_t beginAt,
+                       size_t endAt,
+                       double targetMinimum,
                        double targetRange)
   {
     if(!(rescaleMinimum || rescaleRange))
@@ -275,36 +515,31 @@ namespace csound
   void Score::load(MidiFile &midiFile)
   {
     std::vector<Event>::clear();
-    for(std::vector<MidiTrack>::iterator trackI = midiFile.midiTracks.begin(); trackI != midiFile.midiTracks.end(); ++trackI)
-      {
-        std::set<MidiEvent*> offEvents;
-        for(std::vector<MidiEvent>::iterator onEventI = (*trackI).begin(); onEventI != (*trackI).end(); ++onEventI)
-          {
-            MidiEvent &noteOnEvent = *onEventI;
-            if(noteOnEvent.isNoteOn())
-              {
-                for(std::vector<MidiEvent>::iterator offEventI = onEventI; offEventI != (*trackI).end(); ++offEventI)
-                  {
-                    MidiEvent &noteOffEvent = *offEventI;
-                    if(noteOnEvent.isMatchingNoteOff(noteOffEvent))
-                      {
-                        if(offEvents.find(&noteOffEvent) == offEvents.end())
-                          {
-                            double status = noteOnEvent.getStatusNybble();
-                            double instrument = noteOnEvent.getChannelNybble();
-                            double time = noteOnEvent.time;
-                            double duration = noteOffEvent.time - noteOnEvent.time;
-                            double key = noteOnEvent.getKey();
-                            double velocity = noteOnEvent.getVelocity();
-                            append(time, duration, status, instrument, key, velocity);
-                            offEvents.insert(&noteOffEvent);
-                            break;
-                          }
-                      }
-                  }
+    for(std::vector<MidiTrack>::iterator trackI = midiFile.midiTracks.begin(); trackI != midiFile.midiTracks.end(); ++trackI) {
+      std::set<MidiEvent> usedNoteOffEvents;
+      for(std::vector<MidiEvent>::iterator onEventI = trackI->begin(); onEventI != trackI->end(); ++onEventI) {
+        const MidiEvent &noteOnEvent = *onEventI;
+        if(noteOnEvent.isNoteOn()) {
+          for(std::vector<MidiEvent>::iterator offEventI = onEventI; offEventI != trackI->end(); ++offEventI) {
+            const MidiEvent &noteOffEvent = *offEventI;
+            if (usedNoteOffEvents.find(noteOffEvent) == usedNoteOffEvents.end()) {
+              if(noteOnEvent.matchesNoteOffEvent(noteOffEvent)) {
+                double status = noteOnEvent.getStatusNybble();
+                double instrument = noteOnEvent.getChannelNybble();
+                double time_ = noteOnEvent.time;
+                double duration = noteOffEvent.time - noteOnEvent.time;
+                double key = noteOnEvent.getKey();
+                double velocity = noteOnEvent.getVelocity();
+                append(time_, duration, status, instrument, key, velocity);
+                fprintf(stderr, "Score::load append(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f)\n", time_, duration, status, instrument, key, velocity);
+                usedNoteOffEvents.insert(noteOffEvent);
+                break;
               }
+            }
           }
+        }
       }
+    }
     findScale();
     sort();
   }
@@ -313,45 +548,51 @@ namespace csound
   {
     findScale();
     sort();
-    // Format 0 file.
+    // Make this a Format 1 file.
     midiFile.clear();
-    MidiTrack midiTrack;
-    midiFile.midiTracks.push_back(midiTrack);
-    for(Score::iterator it = begin(); it != end(); ++it)
-      {
-        Event &event = (*it);
-        // event.dump(std::cout);
-        if(event.isNoteOn())
-          {
-            MidiEvent onEvent;
-            onEvent.time = event.getTime();
-            onEvent.ticks = int(Conversions::round(onEvent.time / midiFile.currentSecondsPerTick));
-            onEvent.push_back(event.getMidiStatus());
-            onEvent.push_back(event.getKeyNumber());
-            onEvent.push_back(event.getVelocityNumber());
-            midiFile.midiTracks[0].push_back(onEvent);
-            MidiEvent offEvent;
-            offEvent.time = event.getTime() + event.getDuration();
-            offEvent.ticks = int(Conversions::round(offEvent.time / midiFile.currentSecondsPerTick));
-            offEvent.push_back(event.getMidiStatus());
-            offEvent.push_back(event.getKeyNumber());
-            offEvent.push_back(0);
-            midiFile.midiTracks[0].push_back(offEvent);
-          }
+    midiFile.midiHeader.type = 1;
+    // Each track contains all events for one instrument
+    // (not the same as MIDI channel).
+    std::map<int, Score> eventsForInstruments;
+    for (Score::iterator it = begin(); it != end(); ++it) {
+      const Event &event = *it;
+      //event.dump(std::cout);
+      if(event.isNoteOn()) {
+        Event onEvent = *it;
+        int instrument = event.getInstrument();
+        eventsForInstruments[instrument].push_back(onEvent);
+        Event offEvent = onEvent;
+        onEvent.createNoteOffEvent(offEvent);
+        eventsForInstruments[instrument].push_back(offEvent);
       }
-    midiFile.midiTracks[0].sort();
-    MidiEvent trackEnd;
-    if(midiFile.midiTracks.size() > 0)
-      {
-        if(midiFile.midiTracks[0].size() > 0)
-          {
-            trackEnd.ticks = midiFile.midiTracks[0][midiFile.midiTracks[0].size() - 1].ticks;
-          }
+    }
+    for (std::map<int, Score>::iterator it = eventsForInstruments.begin();
+         it != eventsForInstruments.end();
+         ++it) {
+      Score &eventsForInstrument = it->second;
+      eventsForInstrument.sort();
+      MidiTrack midiTrack;
+      for (size_t i = 0, n = eventsForInstrument.size(); i < n; i++) {
+        const Event &event = eventsForInstrument[i];
+        MidiEvent midiEvent;
+        midiEvent.time = event.getTime();
+        midiEvent.ticks = int(Conversions::round(midiEvent.time / midiFile.currentSecondsPerTick));
+        midiEvent.push_back(event.getMidiStatus());
+        midiEvent.push_back(event.getKeyNumber());
+        midiEvent.push_back(event.getVelocity());
+        midiTrack.push_back(midiEvent);
       }
-    trackEnd.push_back(MidiFile::META_EVENT);
-    trackEnd.push_back(MidiFile::META_END_OF_TRACK);
-    trackEnd.push_back(0);
-    midiFile.midiTracks[0].push_back(trackEnd);
+      MidiEvent trackEnd;
+      trackEnd.ticks = midiTrack.back().ticks;
+      trackEnd.time = midiTrack.back().time;
+      trackEnd.push_back(MidiFile::META_EVENT);
+      trackEnd.push_back(MidiFile::META_END_OF_TRACK);
+      trackEnd.push_back(0);
+      midiTrack.push_back(trackEnd);
+      midiFile.midiTracks.push_back(midiTrack);
+      System::inform("Saved MIDI track for instrument %3d (MIDI channel %3d) with %7d events.\n", it->first, it->first % 16, it->second.size());
+    }
+    midiFile.midiHeader.trackCount = midiFile.midiTracks.size();
   }
 
   void Score::dump(std::ostream &stream)
@@ -403,10 +644,10 @@ namespace csound
     rescaleRanges[Event::HOMOGENEITY] = false;
   }
 
-  void Score::append(double time, double duration, double status, double instrument, double key, double velocity, double phase, double pan, double depth, double height, double pitches)
+  void Score::append(double time_, double duration, double status, double instrument, double key, double velocity, double phase, double pan, double depth, double height, double pitches)
   {
     Event event;
-    event.setTime(time);
+    event.setTime(time_);
     event.setDuration(duration);
     event.setStatus(status);
     event.setInstrument(instrument);
@@ -427,7 +668,7 @@ namespace csound
 
   void Score::sort()
   {
-    std::sort(begin(), end(), std::less<Event>());
+    std::sort(begin(), end());
   }
 
   double Score::getDuration()
@@ -460,7 +701,7 @@ namespace csound
       if( gains.find( oldInstrument ) != gains.end() ) {
         double inputDb = it->getVelocity();
         double gain = gains[oldInstrument];
-        double outputDb = Conversions::gainToDb( inputDb, gain );
+        double outputDb = inputDb + gain;
         it->setVelocity( outputDb );
       }
       if( pans.find( oldInstrument ) != pans.end() ) {
@@ -561,10 +802,10 @@ namespace csound
     }
   }
 
-  std::vector<double> Score::getPTV(size_t begin_, 
-                                    size_t end_, 
-                                    double lowest, 
-                                    double range, 
+  std::vector<double> Score::getPTV(size_t begin_,
+                                    size_t end_,
+                                    double lowest,
+                                    double range,
                                     size_t divisionsPerOctave_) const
   {
     if (begin_ < 0) {
@@ -582,13 +823,13 @@ namespace csound
     return ptv;
   }
 
-  void Score::setPTV(size_t begin_, 
-                     size_t end_, 
-                     double P, 
-                     double T, 
-                     double V, 
-                     double lowest, 
-                     double range, 
+  void Score::setPTV(size_t begin_,
+                     size_t end_,
+                     double P,
+                     double T,
+                     double V,
+                     double lowest,
+                     double range,
                      size_t divisionsPerOctave_)
   {
     if (begin_ < 0) {
@@ -608,10 +849,10 @@ namespace csound
     System::inform("ENDED Score::setPTV.\n");
   }
 
-  std::vector<double> Score::getPT(size_t begin_, 
-                                   size_t end_, 
-                                   double lowest, 
-                                   double range, 
+  std::vector<double> Score::getPT(size_t begin_,
+                                   size_t end_,
+                                   double lowest,
+                                   double range,
                                    size_t divisionsPerOctave_) const
   {
     if (begin_ < 0) {
@@ -630,12 +871,12 @@ namespace csound
     return pt;
   }
 
-  void Score::setPT(size_t begin_, 
-                    size_t end_, 
-                    double P, 
-                    double T, 
-                    double lowest, 
-                    double range, 
+  void Score::setPT(size_t begin_,
+                    size_t end_,
+                    double P,
+                    double T,
+                    double lowest,
+                    double range,
                     size_t divisionsPerOctave_)
   {
     if (begin_ < 0) {
@@ -654,12 +895,12 @@ namespace csound
     std::vector<double> result = getPitches(begin_, end_, divisionsPerOctave_);
     printChord("  result:              ", result);
     std::vector<double> resultTones = Voicelead::uniquePcs(result, divisionsPerOctave_);
-    printChord("  as pitch-class set:  ", resultTones);  
+    printChord("  as pitch-class set:  ", resultTones);
     System::inform("ENDED Score::setPT.\n");
   }
 
-  std::vector<double> Score::getVoicing(size_t begin_, 
-                                        size_t end_, 
+  std::vector<double> Score::getVoicing(size_t begin_,
+                                        size_t end_,
                                         size_t divisionsPerOctave_) const
   {
     System::inform("BEGAN Score::getVoicing(%d, %d, %d)...\n", begin_, end_, divisionsPerOctave_);
@@ -677,15 +918,15 @@ namespace csound
     std::sort(voicing.begin(), voicing.end());
     printChord("  voicing:             ", voicing);
     std::vector<double> resultTones = Voicelead::uniquePcs(voicing, divisionsPerOctave_);
-    printChord("  as pitch-class set:  ", resultTones);  
+    printChord("  as pitch-class set:  ", resultTones);
     System::inform("ENDED Score::getVoicing.\n");
     return voicing;
   }
 
-  void Score::setVoicing(size_t begin_, 
-                         size_t end_, 
-                         const std::vector<double> &voicing, 
-                         double range, 
+  void Score::setVoicing(size_t begin_,
+                         size_t end_,
+                         const std::vector<double> &voicing,
+                         double range,
                          size_t divisionsPerOctave_)
   {
     if (begin_ < 0) {
@@ -714,7 +955,7 @@ namespace csound
       }
       event.setKey(pitch);
     }
-   }
+  }
 
   void Score::voicelead(size_t beginSource,
                         size_t endSource,
@@ -807,7 +1048,7 @@ namespace csound
     std::vector<double> result = getPitches(beginTarget, endTarget, divisionsPerOctave_);
     printChord("  result:              ", result);
     std::vector<double> resultTones = Voicelead::uniquePcs(result, divisionsPerOctave_);
-    printChord("  as pitch-class set:  ", resultTones);  
+    printChord("  as pitch-class set:  ", resultTones);
     System::inform("ENDED Score::voicelead.\n");
   }
 
@@ -860,12 +1101,12 @@ namespace csound
       std::vector<double> result = getPitches(beginTarget, endTarget, divisionsPerOctave_);
       printChord("  result:              ", result);
       std::vector<double> resultTones = Voicelead::uniquePcs(result, divisionsPerOctave_);
-      printChord("  as pitch-class set:  ", resultTones);  
+      printChord("  as pitch-class set:  ", resultTones);
       return;
     }
     std::vector<double> source = getVoicing(beginSource, endSource, divisionsPerOctave_);
     printChord("  source voicing:      ", source);
-     if (source.size() == 0) {
+    if (source.size() == 0) {
       return;
     }
     if (target.size() == 0) {
@@ -907,7 +1148,7 @@ namespace csound
     std::vector<double> result = getPitches(beginTarget, endTarget, divisionsPerOctave_);
     printChord("  result:              ", result);
     std::vector<double> resultTones = Voicelead::uniquePcs(result, divisionsPerOctave_);
-    printChord("  as pitch-class set:  ", resultTones);  
+    printChord("  as pitch-class set:  ", resultTones);
     System::inform("ENDED Score::voicelead.\n");
   }
 
@@ -927,10 +1168,10 @@ namespace csound
     }
   };
 
-  int Score::indexAtTime(double time)
+  int Score::indexAtTime(double time_)
   {
     int index = size();
-    std::vector<Event>::iterator it = std::find_if(begin(), end(), TimeAtComparator(time));
+    std::vector<Event>::iterator it = std::find_if(begin(), end(), TimeAtComparator(time_));
     if (it != end()) {
       index = (it - begin());
     }
@@ -953,10 +1194,10 @@ namespace csound
     }
   };
 
-  int Score::indexAfterTime(double time)
+  int Score::indexAfterTime(double time_)
   {
     int index = size();
-    std::vector<Event>::iterator it = std::find_if(begin(), end(), TimeAfterComparator(time));
+    std::vector<Event>::iterator it = std::find_if(begin(), end(), TimeAfterComparator(time_));
     if (it != end()) {
       index = (it - begin());
     }
@@ -965,11 +1206,11 @@ namespace csound
 
   double Score::indexToTime(size_t index)
   {
-    double time = DBL_MAX;
+    double time_ = DBL_MAX;
     if (index >= 0 && index < size()) {
-      time = (*this)[index].getTime();
+      time_ = (*this)[index].getTime();
     }
-    return time;
+    return time_;
   }
 
   void Score::setDuration(double targetDuration)
@@ -981,10 +1222,15 @@ namespace csound
     double factor = targetDuration / currentDuration;
     for (size_t i = 0, n = size(); i < n; i++) {
       Event &event = (*this)[i];
-      double time = event.getTime();
+      double time_ = event.getTime();
       double duration = event.getDuration();
-      event.setTime(time * factor);
+      event.setTime(time_ * factor);
       event.setDuration(duration * factor);
     }
   }
+  
+  void Score::remove(size_t index)
+  {
+    erase(begin() + index);
+  }
 }
