@@ -21,16 +21,9 @@
  */
 #include "CsoundVST.hpp"
 #include "CsoundVstFltk.hpp"
-#include <Python.h>
 #include <cstring>
 #include <cstdlib>
 
-// Stub to avoid bringing in Python.
-
-void CppSound::setPythonMessageCallback()
-{
-}
-
 static char *dupstr(const char *string)
 {
   if (string == 0) {
